@@ -36,14 +36,10 @@ PORTABILITY
 No supporting OS subroutines are required.
 */
 
-#include <_ansi.h>
 #include <ctype.h>
 
-
-
-#undef isblank
 int
 isblank (int c)
 {
-	return ((__CTYPE_PTR[c+1] & _B) || (c == '\t'));
+    return c == ' ' || c == '\t';
 }
