@@ -89,6 +89,14 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 # endif
 #endif
 
+#if __SIZEOF_DOUBLE__ == __SIZEOF_FLOAT__
+# define _DBL_EQ_FLT
+#endif
+
+#if __SIZEOF_LONG_DOUBLE == __SIZEOF_DOUBLE__
+# define LDBL_EQ_DBL
+#endif
+
 #if __SIZEOF_DOUBLE__ == 4
 # define _DOUBLE_IS_32BITS
 #endif
@@ -97,26 +105,6 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 # define _LONG_DOUBLE_IS_32BITS
 #endif
 
-#if defined(__SIZEOF_LONG_DOUBLE__)
-#define _HAVE_LONG_DOUBLE
-#endif
-
-#if defined(__SIZEOF_DOUBLE__) && defined(__SIZEOF_LONG_DOUBLE__)
-# if __SIZEOF_DOUBLE__ == __SIZEOF_LONG_DOUBLE__
-#  define _LDBL_EQ_DBL
-# else
-#  undef _LDBL_EQ_DBL
-# endif
-#endif
-
-#if defined(__SIZEOF_FLOAT__) && defined(__SIZEOF_DOUBLE__)
-# if __SIZEOF_FLOAT__ == __SIZEOF_DOUBLE__
-#  define _DBL_EQ_FLT
-# else
-#  undef _DBL_EQ_FLT
-#endif
-#endif
-
 #if (defined(__arm__) || defined(__thumb__)) && !defined(__MAVERICK__)
 /* arm with hard fp and soft dp cannot use new float code */
 # if (__ARM_FP & 4) && !(__ARM_FP & 8)
@@ -216,6 +204,9 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 #if defined(__m68k__) || defined(__mc68000__)
 #define __IEEE_BIG_ENDIAN
+#ifdef __HAVE_68881__
+# define _SUPPORTS_ERREXCEPT
+#endif
 #endif
 
 #if defined(__mc68hc11__) || defined(__mc68hc12__) || defined(__mc68hc1x__)
@@ -239,13 +230,14 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 
 #ifdef __sh__
-#ifdef __LITTLE_ENDIAN__
+#define _IEEE_754_2008_SNAN 0
+#if __FLOAT_WORD_ORDER__ == __ORDER_LITTLE_ENDIAN__
 #define __IEEE_LITTLE_ENDIAN
-#else
+#elif __FLOAT_WORD_ORDER__ == __ORDER_BIG_ENDIAN__
 #define __IEEE_BIG_ENDIAN
 #endif
-#if defined(__SH2E__) || defined(__SH3E__) || defined(__SH4_SINGLE_ONLY__) || defined(__SH2A_SINGLE_ONLY__)
-#define _DOUBLE_IS_32BITS
+#ifdef __SH_FPU_ANY__
+#define _SUPPORTS_ERREXCEPT
 #endif
 #endif
 
@@ -259,8 +251,10 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 #ifdef __i386__
 #define __IEEE_LITTLE_ENDIAN
+#ifndef _SOFT_FLOAT
 # define _SUPPORTS_ERREXCEPT
 #endif
+#endif
 
 #ifdef __riscv
 #if defined(__BYTE_ORDER__) && (__BYTE_ORDER__ == __ORDER_BIG_ENDIAN__)
@@ -268,7 +262,7 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #else
 #define __IEEE_LITTLE_ENDIAN
 #endif
-#ifdef __riscv_flen
+#if defined(__riscv_flen) || defined (__riscv_zfinx)
 # define _SUPPORTS_ERREXCEPT
 #endif
 #endif
@@ -320,6 +314,13 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #define __IEEE_LITTLE_ENDIAN
 #endif
 
+#ifdef __mips__
+#define _IEEE_754_2008_SNAN 0
+#ifndef __mips_soft_float
+#define _SUPPORTS_ERREXCEPT
+#endif
+#endif
+
 #ifdef __MIPSEL__
 #define __IEEE_LITTLE_ENDIAN
 #endif
@@ -488,8 +489,10 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 #ifdef __x86_64__
 #define __IEEE_LITTLE_ENDIAN
+#ifndef _SOFT_FLOAT
 # define _SUPPORTS_ERREXCEPT
 #endif
+#endif
 
 #ifdef __mep__
 #ifdef __LITTLE_ENDIAN__
@@ -577,9 +580,15 @@ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #undef __OBSOLETE_MATH
 #undef __OBSOLETE_MATH_DOUBLE
 #undef __OBSOLETE_MATH_FLOAT
+#undef __OBSOLETE_MATH_DEFAULT_FLOAT
+#undef __OBSOLETE_MATH_DEFAULT_DOUBLE
 #define __OBSOLETE_MATH 1
 #endif
 
+#ifdef __XTENSA_EB__
+#define __IEEE_BIG_ENDIAN
+#endif
+
 #ifdef __CYGWIN__
 #define __OBSOLETE_MATH_DEFAULT 0
 #endif
