@@ -64,6 +64,7 @@ typedef __WINT_TYPE__ wint_t;
 
 #ifndef __machine_blkcnt_t_defined
 typedef long __blkcnt_t;
+typedef __int64_t __blkcnt64_t;
 #endif
 
 #ifndef __machine_blksize_t_defined
@@ -122,6 +123,7 @@ typedef unsigned long __ino_t;
 #else
 typedef unsigned short __ino_t;
 #endif
+typedef __uint64_t      __ino64_t;
 #endif
 
 #ifndef __machine_mode_t_defined
@@ -148,6 +150,7 @@ __extension__ typedef long long _off64_t;
 typedef _off64_t __off_t;
 #else
 typedef _off_t __off_t;
+typedef __uint64_t __off64_t;
 #endif
 
 typedef _off64_t __loff_t;
