@@ -107,6 +107,57 @@ struct	stat
 #endif
 };
 
+struct stat64
+{
+  __dev_t st_dev;		/* Device.  */
+#  ifdef __x86_64__
+  __ino64_t st_ino;		/* File serial number.  */
+  __nlink_t st_nlink;		/* Link count.  */
+  __mode_t st_mode;		/* File mode.  */
+#  else
+  unsigned int __pad1;
+  __ino_t __st_ino;			/* 32bit file serial number.	*/
+  __mode_t st_mode;			/* File mode.  */
+  __nlink_t st_nlink;			/* Link count.  */
+#  endif
+  __uid_t st_uid;		/* User ID of the file's owner.	*/
+  __gid_t st_gid;		/* Group ID of the file's group.*/
+#  ifdef __x86_64__
+  int __pad0;
+  __dev_t st_rdev;		/* Device number, if device.  */
+  __off_t st_size;		/* Size of file, in bytes.  */
+#  else
+  __dev_t st_rdev;			/* Device number, if device.  */
+  unsigned int __pad2;
+  __off64_t st_size;			/* Size of file, in bytes.  */
+#  endif
+  __blksize_t st_blksize;	/* Optimal block size for I/O.  */
+  __blkcnt64_t st_blocks;	/* Nr. 512-byte blocks allocated.  */
+#if defined(__svr4__) && !defined(__PPC__) && !defined(__sun__)
+  __time_t st_atime;			/* Time of last access.  */
+  __syscall_ulong_t st_atimensec;	/* Nscecs of last access.  */
+  __time_t st_mtime;			/* Time of last modification.  */
+  __syscall_ulong_t st_mtimensec;	/* Nsecs of last modification.  */
+  __time_t st_ctime;			/* Time of last status change.  */
+  __syscall_ulong_t st_ctimensec;	/* Nsecs of last status change.  */
+#else
+  /* Nanosecond resolution timestamps are stored in a format
+     equivalent to 'struct timespec'.  This is the type used
+     whenever possible but the Unix namespace rules do not allow the
+     identifier 'timespec' to appear in the <sys/stat.h> header.
+     Therefore we have to handle the use of this header in strictly
+     standard-compliant sources special.  */
+  struct timespec st_atim;		/* Time of last access.  */
+  struct timespec st_mtim;		/* Time of last modification.  */
+  struct timespec st_ctim;		/* Time of last status change.  */
+#  endif
+#  ifdef __x86_64__
+  __int64_t __glibc_reserved[3];
+#  else
+  __ino64_t st_ino;			/* File serial number.		*/
+#  endif
+};
+
 #if !(defined(__svr4__) && !defined(__PPC__) && !defined(__sun__))
 #define st_atime st_atim.tv_sec
 #define st_ctime st_ctim.tv_sec
@@ -199,7 +250,7 @@ int	mkfifo (const char *__path, mode_t __mode );
 int	stat (const char *__restrict __path, struct stat *__restrict __sbuf );
 mode_t	umask (mode_t __mask );
 
-#if defined (__SPU__) || defined(__rtems__) || defined(__CYGWIN__) && !defined(__INSIDE_CYGWIN__)
+#if defined (__SPU__) || defined(__rtems__) || defined(__CYGWIN__)
 int	lstat (const char *__restrict __path, struct stat *__restrict __buf );
 int	mknod (const char *__path, mode_t __mode, dev_t __dev );
 #endif
