@@ -75,7 +75,6 @@ typedef __intptr_t register_t;
 
 #if __BSD_VISIBLE
 #include <machine/endian.h>
-#include <sys/select.h>
 #  define	physadr		physadr_t
 #  define	quad		quad_t
 
@@ -143,10 +142,8 @@ typedef	_TIME_T_	time_t;
 #define	_TIME_T_DECLARED
 #endif
 
-#ifndef __daddr_t_defined
-typedef	long	daddr_t;
-#define __daddr_t_defined
-#endif
+typedef	__daddr_t	daddr_t;
+
 #ifndef __caddr_t_defined
 typedef	char *	caddr_t;
 #define __caddr_t_defined
