@@ -50,7 +50,6 @@ extern struct __locale_t __global_locale;
 #ifdef __CYGWIN__
 struct lc_collate_T
 {
-  __uint32_t	 lcid;
   int	       (*mbtowc) (wchar_t *, const char *, size_t,
 			  mbstate_t *);
   char		 codeset[ENCODING_LEN + 1];
@@ -68,6 +67,9 @@ struct lc_ctype_T
 #endif
 };
 extern const struct lc_ctype_T _C_ctype_locale;
+#ifdef __CYGWIN__
+extern const struct lc_ctype_T _C_utf8_ctype_locale;
+#endif
 
 struct lc_monetary_T
 {
