@@ -33,10 +33,10 @@
 /* Support the alias for the __aeabi_memset which may
    assume memory alignment.  */
 void __aeabi_memset4 (void *dest, size_t n, int c)
-	_ATTRIBUTE ((alias ("__aeabi_memset")));
+	_ATTRIBUTE ((alias ("__aeabi_memset"), weak));
 
 void __aeabi_memset8 (void *dest, size_t n, int c)
-	_ATTRIBUTE ((alias ("__aeabi_memset")));
+	_ATTRIBUTE ((alias ("__aeabi_memset"), weak));
 
 /* Support the routine __aeabi_memset.  Can't alias to memset
    because the arguments are in a different order */
@@ -47,7 +47,7 @@ void __aeabi_memset8 (void *dest, size_t n, int c)
 
 #undef memset
 
-void __attribute__((used)) __aeabi_memset (void *dest, size_t n, int c)
+void __attribute__((used, weak)) __aeabi_memset (void *dest, size_t n, int c)
 {
   /*Note that relative to ANSI memset, __aeabi_memset hase the order
     of its second and third arguments reversed.  */
