@@ -38,8 +38,15 @@
 #ifndef _MACHINE_MATH_H_
 #define _MACHINE_MATH_H_
 
-#if defined(_HAVE_ATTRIBUTE_ALWAYS_INLINE) && defined(_HAVE_ATTRIBUTE_GNU_INLINE)
-#define __declare_arm_macro(type) extern __inline type __attribute((gnu_inline, always_inline))
+# if (__ARM_FEATURE_FMA && (__ARM_FP & 8))
+#define _HAVE_FAST_FMA  1
+#endif
+
+#if (__ARM_FEATURE_FMA && (__ARM_FP & 4))
+#define _HAVE_FAST_FMAF 1
+#endif
+
+#ifdef __declare_extern_inline
 
 #ifdef _WANT_MATH_ERRNO
 #include <errno.h>
@@ -51,25 +58,33 @@
  * Double precision routines
  */
 
-__declare_arm_macro(double)
+__declare_extern_inline(double)
 sqrt(double x)
 {
 	double result;
 #ifdef _WANT_MATH_ERRNO
-        if (x < 0)
+        if (isless(x, 0.0))
             errno = EDOM;
 #endif
 #if __ARM_ARCH >= 6
-	__asm__("vsqrt.f64 %P0, %P1" : "=w" (result) : "w" (x));
+	__asm__ volatile ("vsqrt.f64 %P0, %P1" : "=w" (result) : "w" (x));
 #else
 	/* VFP9 Erratum 760019, see GCC sources "gcc/config/arm/vfp.md" */
-	__asm__("vsqrt.f64 %P0, %P1" : "=&w" (result) : "w" (x));
+        __asm__ volatile ("vsqrt.f64 %P0, %P1" : "=&w" (result) : "w" (x));
 #endif
 	return result;
 }
 
+__declare_extern_inline(double)
+fabs(double x)
+{
+    double result;
+    __asm__ ("vabs.f64\t%P0, %P1" : "=w" (result) : "w" (x));
+    return result;
+}
+
 #if __ARM_ARCH >= 8
-__declare_arm_macro(double)
+__declare_extern_inline(double)
 ceil (double x)
 {
   double result;
@@ -77,7 +92,7 @@ ceil (double x)
   return result;
 }
 
-__declare_arm_macro(double)
+__declare_extern_inline(double)
 floor (double x)
 {
   double result;
@@ -85,15 +100,22 @@ floor (double x)
   return result;
 }
 
-__declare_arm_macro(double)
+__declare_extern_inline(double)
 nearbyint (double x)
 {
-  double result;
-  __asm__ volatile ("vrintr.f64\t%P0, %P1" : "=w" (result) : "w" (x));
-  return result;
+    if (isnan(x)) return x + x;
+#if defined(FE_INEXACT)
+    fenv_t env;
+    fegetenv(&env);
+#endif
+    __asm__ volatile ("vrintr.f64\t%P0, %P1" : "=w" (x) : "w" (x));
+#if defined(FE_INEXACT)
+    fesetenv(&env);
+#endif
+    return x;
 }
 
-__declare_arm_macro(double)
+__declare_extern_inline(double)
 rint (double x)
 {
   double result;
@@ -101,7 +123,7 @@ rint (double x)
   return result;
 }
 
-__declare_arm_macro(double)
+__declare_extern_inline(double)
 round (double x)
 {
   double result;
@@ -109,7 +131,7 @@ round (double x)
   return result;
 }
 
-__declare_arm_macro(double)
+__declare_extern_inline(double)
 trunc (double x)
 {
   double result;
@@ -118,13 +140,15 @@ trunc (double x)
 }
 #endif /* __ARM_ARCH >= 8 */
 
-#if HAVE_FAST_FMA
-__declare_arm_macro(double)
+#if _HAVE_FAST_FMA
+
+__declare_extern_inline(double)
 fma (double x, double y, double z)
 {
-  __asm__("vfma.f64 %P0, %P1, %P2" : "+w" (z) : "w" (x), "w" (y));
+  __asm__ volatile ("vfma.f64 %P0, %P1, %P2" : "+w" (z) : "w" (x), "w" (y));
   return z;
 }
+
 #endif
 
 #endif /* (__ARM_FP & 0x8) && !defined(__SOFTFP__) */
@@ -135,25 +159,33 @@ fma (double x, double y, double z)
  * Single precision functions
  */
 
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 sqrtf(float x)
 {
 	float result;
 #ifdef _WANT_MATH_ERRNO
-        if (x < 0)
+        if (isless(x, 0.0f))
             errno = EDOM;
 #endif
 #if __ARM_ARCH >= 6
-	__asm__("vsqrt.f32 %0, %1" : "=w" (result) : "w" (x));
+	__asm__ volatile ("vsqrt.f32 %0, %1" : "=w" (result) : "w" (x));
 #else
 	/* VFP9 Erratum 760019, see GCC sources "gcc/config/arm/vfp.md" */
-	__asm__("vsqrt.f32 %0, %1" : "=&w" (result) : "w" (x));
+	__asm__ volatile ("vsqrt.f32 %0, %1" : "=&w" (result) : "w" (x) : "cc", "memory");
 #endif
 	return result;
 }
 
+__declare_extern_inline(float)
+fabsf(float x)
+{
+    float result;
+    __asm__ ("vabs.f32\t%0, %1" : "=t" (result) : "t" (x));
+    return result;
+}
+
 #if __ARM_ARCH >= 8
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 ceilf (float x)
 {
   float result;
@@ -161,7 +193,7 @@ ceilf (float x)
   return result;
 }
 
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 floorf (float x)
 {
   float result;
@@ -169,15 +201,22 @@ floorf (float x)
   return result;
 }
 
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 nearbyintf (float x)
 {
-  float result;
-  __asm__ volatile ("vrintr.f32\t%0, %1" : "=t" (result) : "t" (x));
-  return result;
+    if (isnan(x)) return x + x;
+#if defined(FE_INEXACT)
+    fenv_t env;
+    fegetenv(&env);
+#endif
+    __asm__ volatile ("vrintr.f32\t%0, %1" : "=t" (x) : "t" (x));
+#if defined(FE_INEXACT)
+    fesetenv(&env);
+#endif
+    return x;
 }
 
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 rintf (float x)
 {
   float result;
@@ -185,7 +224,7 @@ rintf (float x)
   return result;
 }
 
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 roundf (float x)
 {
   float result;
@@ -193,7 +232,7 @@ roundf (float x)
   return result;
 }
 
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 truncf (float x)
 {
   float result;
@@ -202,20 +241,19 @@ truncf (float x)
 }
 #endif /* __ARM_ARCH >= 8 */
 
-#if HAVE_FAST_FMAF
+#if _HAVE_FAST_FMAF
 
-__declare_arm_macro(float)
+__declare_extern_inline(float)
 fmaf (float x, float y, float z)
 {
-  __asm__("vfma.f32 %0, %1, %2" : "+t" (z) : "t" (x), "t" (y));
+  __asm__ volatile ("vfma.f32 %0, %1, %2" : "+t" (z) : "t" (x), "t" (y));
   return z;
 }
+
 #endif
 
 #endif /* (__ARM_FP & 0x4) && !defined(__SOFTFP__) */
 
-#undef __declare_arm_macro
-
 #endif /* have attributes */
 
 #endif /* _MACHINE_MATH_H_ */
