@@ -47,12 +47,12 @@
 # include "../../string/memcpy.c"
 
 void *__aeabi_memcpy4 (void *__restrict dest, const void * __restrict source, size_t n)
-	_ATTRIBUTE ((alias ("memcpy")));
+	_ATTRIBUTE ((alias ("memcpy"), weak));
 
 void *__aeabi_memcpy8 (void * __restrict dest, const void * __restrict source, size_t n)
-	_ATTRIBUTE ((alias ("memcpy")));
+	_ATTRIBUTE ((alias ("memcpy"), weak));
 
 void *__aeabi_memcpy (void * __restrict dest, const void * __restrict source, size_t n)
-	_ATTRIBUTE ((alias ("memcpy")));
+	_ATTRIBUTE ((alias ("memcpy"), weak));
 
 #endif
