@@ -31,7 +31,6 @@
 #ifndef _SYS_FENV_H_
 #define _SYS_FENV_H_ 1
 
-#include <sys/_types.h>
 #include <sys/cdefs.h>
 
 #ifdef __cplusplus
@@ -72,8 +71,20 @@ typedef int fexcept_t;
 
 #endif
 
+#if !defined(__declare_fenv_inline) && defined(__declare_extern_inline)
+#define	__declare_fenv_inline(type) __declare_extern_inline(type)
+#endif
+
+#ifdef __declare_fenv_inline
+#ifdef __SOFTFP__
+#include <machine/fenv-softfloat.h>
+#else
+#include <machine/fenv-fp.h>
+#endif
+#endif
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif	/* _SYS_FENV_H_ */ 
+#endif	/* _SYS_FENV_H_ */
