@@ -34,6 +34,7 @@
  */
 
 #include <unistd.h>
+#include <errno.h>
 
 extern char __heap_start[];
 extern char __heap_end[];
@@ -43,11 +44,15 @@ static char *brk = __heap_start;
 void *sbrk(ptrdiff_t incr)
 {
 	if (incr < 0) {
-		if (brk - __heap_start < -incr)
-			return (void *) -1;
+                if ((size_t) (brk - __heap_start) < (size_t) (-incr)) {
+                    errno = ENOMEM;
+                    return (void *) -1;
+            }
 	} else {
-		if (__heap_end - brk < incr)
+                if ((size_t) (__heap_end - brk) < (size_t) incr) {
+                        errno = ENOMEM;
 			return (void *) -1;
+                }
 	}
 	void *ret = brk;
 	brk += incr;
