@@ -22,9 +22,9 @@ SYNOPSIS
 	int dprintf(int <[fd]>, const char *restrict <[format]>, ...);
 	int vdprintf(int <[fd]>, const char *restrict <[format]>,
 			va_list <[ap]>);
-	int _dprintf_r(struct _reent *<[ptr]>, int <[fd]>,
+	int dprintf( int <[fd]>,
 			const char *restrict <[format]>, ...);
-	int _vdprintf_r(struct _reent *<[ptr]>, int <[fd]>,
+	int vdprintf( int <[fd]>,
 			const char *restrict <[format]>, va_list <[ap]>);
 
 DESCRIPTION
@@ -52,39 +52,16 @@ Supporting OS subroutines required: <<sbrk>>, <<write>>.
 #include <stdarg.h>
 #include "local.h"
 
-int
-_dprintf_r (struct _reent *ptr,
-       int fd,
-       const char *__restrict format, ...)
-{
-	va_list ap;
-	int n;
-	_REENT_SMALL_CHECK_INIT (ptr);
-	va_start (ap, format);
-	n = _vdprintf_r (ptr, fd, format, ap);
-	va_end (ap);
-	return n;
-}
-
-#ifdef _NANO_FORMATTED_IO
-int
-_diprintf_r (struct _reent *, int, const char *, ...)
-       _ATTRIBUTE ((__alias__("_dprintf_r")));
-#endif
-
-#ifndef _REENT_ONLY
-
 int
 dprintf (int fd,
        const char *__restrict format, ...)
 {
   va_list ap;
   int n;
-  struct _reent *ptr = _REENT;
 
   _REENT_SMALL_CHECK_INIT (ptr);
   va_start (ap, format);
-  n = _vdprintf_r (ptr, fd, format, ap);
+  n = vdprintf ( fd, format, ap);
   va_end (ap);
   return n;
 }
@@ -94,4 +71,3 @@ int
 diprintf (int, const char *, ...)
        _ATTRIBUTE ((__alias__("dprintf")));
 #endif
-#endif /* ! _REENT_ONLY */
