@@ -27,7 +27,7 @@ INDEX
 SYNOPSIS
 	#include <stdio.h>
 	int fclose(FILE *<[fp]>);
-	int _fclose_r(struct _reent *<[reent]>, FILE *<[fp]>);
+	int fclose( FILE *<[fp]>);
 
 DESCRIPTION
 If the file or stream identified by <[fp]> is open, <<fclose>> closes
@@ -56,7 +56,7 @@ Required OS subroutines: <<close>>, <<fstat>>, <<isatty>>, <<lseek>>,
 #include "local.h"
 
 int
-_fclose_r (struct _reent *rptr,
+fclose (
       register FILE * fp)
 {
   int r;
@@ -86,14 +86,14 @@ _fclose_r (struct _reent *rptr,
     }
 #ifdef _STDIO_BSD_SEMANTICS
   /* BSD and Glibc systems only flush streams which have been written to. */
-  r = (fp->_flags & __SWR) ? __sflush_r (rptr, fp) : 0;
+  r = (fp->_flags & __SWR) ? _sflush ( fp) : 0;
 #else
   /* Follow POSIX semantics exactly.  Unconditionally flush to allow
      special handling for seekable read files to reposition file to last
      byte processed as opposed to last byte read ahead into the buffer. */
-  r = __sflush_r (rptr, fp);
+  r = _sflush ( fp);
 #endif
-  if (fp->_close != NULL && fp->_close (rptr, fp->_cookie) < 0)
+  if (fp->_close != NULL && fp->_close (fp->_cookie) < 0)
     r = EOF;
   if (fp->_flags & __SMBF)
     free ((char *) fp->_bf._base);
@@ -116,13 +116,3 @@ _fclose_r (struct _reent *rptr,
 
   return (r);
 }
-
-#ifndef _REENT_ONLY
-
-int
-fclose (register FILE * fp)
-{
-  return _fclose_r(_REENT, fp);
-}
-
-#endif
