@@ -27,7 +27,7 @@ INDEX
 SYNOPSIS
 	#include <stdio.h>
 	FILE *fdopen(int <[fd]>, const char *<[mode]>);
-	FILE *_fdopen_r(struct _reent *<[reent]>,
+	FILE *fdopen(
                         int <[fd]>, const char *<[mode]>);
 
 DESCRIPTION
@@ -53,32 +53,32 @@ PORTABILITY
 #include <_syslist.h>
 
 FILE *
-_fdopen_r (struct _reent *ptr,
+fdopen (
        int fd,
        const char *mode)
 {
   register FILE *fp;
   int flags, oflags;
-#ifdef HAVE_FCNTL
+#ifdef _HAVE_FCNTL
   int fdflags, fdmode;
 #endif
 
-  if ((flags = __sflags (ptr, mode, &oflags)) == 0)
+  if ((flags = __sflags (mode, &oflags)) == 0)
     return 0;
 
   /* make sure the mode the user wants is a subset of the actual mode */
-#ifdef HAVE_FCNTL
+#ifdef _HAVE_FCNTL
   if ((fdflags = fcntl (fd, F_GETFL, 0)) < 0)
     return 0;
   fdmode = fdflags & O_ACCMODE;
   if (fdmode != O_RDWR && (fdmode != (oflags & O_ACCMODE)))
     {
-      __errno_r(ptr) = EBADF;
+      _REENT_ERRNO(ptr) = EBADF;
       return 0;
     }
 #endif
 
-  if ((fp = __sfp (ptr)) == 0)
+  if ((fp = __sfp ()) == 0)
     return 0;
 
   _newlib_flockfile_start (fp);
@@ -88,7 +88,7 @@ _fdopen_r (struct _reent *ptr,
      streams.  Someone may later clear O_APPEND on fileno(fp), but the
      stream must still remain in append mode.  Rely on __sflags
      setting __SAPP properly.  */
-#ifdef HAVE_FCNTL
+#ifdef _HAVE_FCNTL
   if ((oflags & O_APPEND) && !(fdflags & O_APPEND))
     fcntl (fd, F_SETFL, fdflags | O_APPEND);
 #endif
@@ -118,14 +118,3 @@ _fdopen_r (struct _reent *ptr,
   _newlib_flockfile_end (fp);
   return fp;
 }
-
-#ifndef _REENT_ONLY
-
-FILE *
-fdopen (int fd,
-       const char *mode)
-{
-  return _fdopen_r (_REENT, fd, mode);
-}
-
-#endif
