@@ -37,11 +37,11 @@ SYNOPSIS
 	int fflush_unlocked(FILE *<[fp]>);
 
 	#include <stdio.h>
-	int _fflush_r(struct _reent *<[reent]>, FILE *<[fp]>);
+	int fflush( FILE *<[fp]>);
 
 	#define _BSD_SOURCE
 	#include <stdio.h>
-	int _fflush_unlocked_r(struct _reent *<[reent]>, FILE *<[fp]>);
+	int fflush_unlocked( FILE *<[fp]>);
 
 DESCRIPTION
 The <<stdio>> output functions can buffer output before delivering it
@@ -101,12 +101,12 @@ No supporting OS subroutines are required.
 /* Core function which does not lock file pointer.  This gets called
    directly from __srefill. */
 int
-__sflush_r (struct _reent *ptr,
+_sflush (
        register FILE * fp)
 {
   register unsigned char *p;
-  register _READ_WRITE_BUFSIZE_TYPE n;
-  register _READ_WRITE_RETURN_TYPE t;
+  register size_t n;
+  register ssize_t t;
   short flags;
 
   flags = fp->_flags;
@@ -138,8 +138,8 @@ __sflush_r (struct _reent *ptr,
 	  /* Save last errno and set errno to 0, so we can check if a device
 	     returns with a valid position -1.  We restore the last errno if
 	     no other error condition has been encountered. */
-	  tmp_errno = __errno_r(ptr);
-	  __errno_r(ptr) = 0;
+	  tmp_errno = _REENT_ERRNO(ptr);
+	  _REENT_ERRNO(ptr) = 0;
 	  /* Get the physical position we are at in the file.  */
 	  if (fp->_flags & __SOFF)
 	    curoff = fp->_offset;
@@ -149,17 +149,17 @@ __sflush_r (struct _reent *ptr,
 		 Only ESPIPE and EINVAL are ignorable.  */
 #ifdef __LARGE64_FILES
 	      if (fp->_flags & __SL64)
-		curoff = fp->_seek64 (ptr, fp->_cookie, 0, SEEK_CUR);
+		curoff = fp->_seek64 (fp->_cookie, 0, SEEK_CUR);
 	      else
 #endif
-		curoff = fp->_seek (ptr, fp->_cookie, 0, SEEK_CUR);
-	      if (curoff == -1L && __errno_r(ptr) != 0)
+		curoff = fp->_seek (fp->_cookie, 0, SEEK_CUR);
+	      if (curoff == -1L && _REENT_ERRNO(ptr) != 0)
 		{
 		  int result = EOF;
-		  if (__errno_r(ptr) == ESPIPE || __errno_r(ptr) == EINVAL)
+		  if (_REENT_ERRNO(ptr) == ESPIPE || _REENT_ERRNO(ptr) == EINVAL)
 		    {
 		      result = 0;
-		      __errno_r(ptr) = tmp_errno;
+		      _REENT_ERRNO(ptr) = tmp_errno;
 		    }
 		  else
 		    fp->_flags |= __SERR;
@@ -177,12 +177,12 @@ __sflush_r (struct _reent *ptr,
 	  /* Now physically seek to after byte last read.  */
 #ifdef __LARGE64_FILES
 	  if (fp->_flags & __SL64)
-	    curoff = fp->_seek64 (ptr, fp->_cookie, curoff, SEEK_SET);
+	    curoff = fp->_seek64 (fp->_cookie, curoff, SEEK_SET);
 	  else
 #endif
-	    curoff = fp->_seek (ptr, fp->_cookie, curoff, SEEK_SET);
-	  if (curoff != -1 || __errno_r(ptr) == 0
-	      || __errno_r(ptr) == ESPIPE || __errno_r(ptr) == EINVAL)
+	    curoff = fp->_seek (fp->_cookie, curoff, SEEK_SET);
+	  if (curoff != -1 || _REENT_ERRNO(ptr) == 0
+	      || _REENT_ERRNO(ptr) == ESPIPE || _REENT_ERRNO(ptr) == EINVAL)
 	    {
 	      /* Seek successful or ignorable error condition.
 		 We can clear read buffer now.  */
@@ -191,9 +191,9 @@ __sflush_r (struct _reent *ptr,
 #endif
 	      fp->_r = 0;
 	      fp->_p = fp->_bf._base;
-	      if ((fp->_flags & __SOFF) && (curoff != -1 || __errno_r(ptr) == 0))
+	      if ((fp->_flags & __SOFF) && (curoff != -1 || _REENT_ERRNO(ptr) == 0))
 		fp->_offset = curoff;
-	      __errno_r(ptr) = tmp_errno;
+	      _REENT_ERRNO(ptr) = tmp_errno;
 	      if (HASUB (fp))
 		FREEUB (ptr, fp);
 	    }
@@ -222,7 +222,7 @@ __sflush_r (struct _reent *ptr,
 
   while (n > 0)
     {
-      t = fp->_write (ptr, fp->_cookie, (char *) p, n);
+      t = fp->_write (fp->_cookie, (char *) p, n);
       if (t <= 0)
 	{
           fp->_flags |= __SERR;
@@ -235,23 +235,25 @@ __sflush_r (struct _reent *ptr,
 }
 
 #ifdef _STDIO_BSD_SEMANTICS
-/* Called from _cleanup_r.  At exit time, we don't need file locking,
+/* Called from cleanup_stdio().  At exit time, we don't need file locking,
    and we don't want to move the underlying file pointer unless we're
    writing. */
 int
-__sflushw_r (struct _reent *ptr,
+_sflushw (
        register FILE *fp)
 {
-  return (fp->_flags & __SWR) ?  __sflush_r (ptr, fp) : 0;
+  return (fp->_flags & __SWR) ?  _sflush ( fp) : 0;
 }
 #endif
 
 #endif /* __IMPL_UNLOCKED__ */
 
 int
-_fflush_r (struct _reent *ptr,
-       register FILE * fp)
+fflush (register FILE * fp)
 {
+  if (fp == NULL)
+    return _fwalk_sglue (fflush, &__sglue);
+
   int ret;
 
 #ifdef _REENT_SMALL
@@ -276,20 +278,7 @@ _fflush_r (struct _reent *ptr,
     return 0;
 
   _newlib_flockfile_start (fp);
-  ret = __sflush_r (ptr, fp);
+  ret = _sflush ( fp);
   _newlib_flockfile_end (fp);
   return ret;
 }
-
-#ifndef _REENT_ONLY
-
-int
-fflush (register FILE * fp)
-{
-  if (fp == NULL)
-    return _fwalk_reent (_GLOBAL_REENT, _fflush_r);
-
-  return _fflush_r (_REENT, fp);
-}
-
-#endif /* _REENT_ONLY */
