@@ -21,8 +21,6 @@
 #include <stdarg.h>
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
 fscanf(FILE *__restrict fp, const char *__restrict fmt, ...)
 {
@@ -30,33 +28,13 @@ fscanf(FILE *__restrict fp, const char *__restrict fmt, ...)
   va_list ap;
 
   va_start (ap, fmt);
-  ret = _vfscanf_r (_REENT, fp, fmt, ap);
+  ret = vfscanf ( fp, fmt, ap);
   va_end (ap);
   return ret;
 }
 
 #ifdef _NANO_FORMATTED_IO
-int
+int __nonnull((1))
 fiscanf (FILE *, const char *, ...)
        _ATTRIBUTE ((__alias__("fscanf")));
 #endif
-
-#endif /* !_REENT_ONLY */
-
-int
-_fscanf_r(struct _reent *ptr, FILE *__restrict fp, const char *__restrict fmt, ...)
-{
-  int ret;
-  va_list ap;
-
-  va_start (ap, fmt);
-  ret = _vfscanf_r (ptr, fp, fmt, ap);
-  va_end (ap);
-  return (ret);
-}
-
-#ifdef _NANO_FORMATTED_IO
-int
-_fiscanf_r (struct _reent *, FILE *, const char *, ...)
-       _ATTRIBUTE ((__alias__("_fscanf_r")));
-#endif
