@@ -71,23 +71,10 @@ static char sccsid[] = "%W% (Berkeley) %G%";
 
 #undef getchar
 
-int
-_getchar_r (struct _reent *reent)
-{
-  _REENT_SMALL_CHECK_INIT (reent);
-  return _getc_r (reent, _stdin_r (reent));
-}
-
-#ifndef _REENT_ONLY
-
 int
 getchar (void)
 {
-  struct _reent *reent = _REENT;
-
   /* CHECK_INIT is called (eventually) by __srefill_r.  */
-  _REENT_SMALL_CHECK_INIT (reent);
-  return _getc_r (reent, _stdin_r (reent));
+  _REENT_SMALL_CHECK_INIT (_REENT);
+  return getc ( stdin );
 }
-
-#endif
