@@ -23,7 +23,7 @@
 #include "local.h"
 
 int
-_printf_r (struct _reent *ptr,
+printf (
        const char *__restrict fmt, ...)
 {
   int ret;
@@ -31,36 +31,13 @@ _printf_r (struct _reent *ptr,
 
   _REENT_SMALL_CHECK_INIT (ptr);
   va_start (ap, fmt);
-  ret = _vfprintf_r (ptr, _stdout_r (ptr), fmt, ap);
+  ret = vfprintf ( _stdout_r (ptr), fmt, ap);
   va_end (ap);
   return ret;
 }
 
 #ifdef _NANO_FORMATTED_IO
-int
-_iprintf_r (struct _reent *, const char *, ...)
-       _ATTRIBUTE ((__alias__("_printf_r")));
-#endif
-
-#ifndef _REENT_ONLY
-
-int
-printf (const char *__restrict fmt, ...)
-{
-  int ret;
-  va_list ap;
-  struct _reent *ptr = _REENT;
-
-  _REENT_SMALL_CHECK_INIT (ptr);
-  va_start (ap, fmt);
-  ret = _vfprintf_r (ptr, _stdout_r (ptr), fmt, ap);
-  va_end (ap);
-  return ret;
-}
-
-#ifdef _NANO_FORMATTED_IO
-int
+int __nonnull((1))
 iprintf (const char *, ...)
        _ATTRIBUTE ((__alias__("printf")));
 #endif
-#endif /* ! _REENT_ONLY */
