@@ -39,10 +39,10 @@ SYNOPSIS
         int fscanf(FILE *restrict <[fd]>, const char *restrict <[format]>, ...);
         int sscanf(const char *restrict <[str]>, const char *restrict <[format]>, ...);
 
-        int _scanf_r(struct _reent *<[ptr]>, const char *restrict <[format]>, ...);
-        int _fscanf_r(struct _reent *<[ptr]>, FILE *restrict <[fd]>, 
+        int scanf( const char *restrict <[format]>, ...);
+        int fscanf( FILE *restrict <[fd]>, 
                       const char *restrict <[format]>, ...);
-        int _sscanf_r(struct _reent *<[ptr]>, const char *restrict <[str]>,
+        int sscanf( const char *restrict <[str]>,
                       const char *restrict <[format]>, ...);
 
 DESCRIPTION
@@ -418,9 +418,7 @@ Supporting OS subroutines required: <<close>>, <<fstat>>, <<isatty>>,
 #include <stdarg.h>
 #include "local.h"
 
-#ifndef _REENT_ONLY 
-
-int 
+int
 sscanf (const char *__restrict str,
        const char * fmt, ...)
 {
@@ -429,6 +427,7 @@ sscanf (const char *__restrict str,
   FILE f;
 
   f._flags = __SRD | __SSTR;
+  f._flags2 = 0;
   f._bf._base = f._p = (unsigned char *) str;
   f._bf._size = f._r = strlen (str);
   f._read = __seofread;
@@ -436,43 +435,13 @@ sscanf (const char *__restrict str,
   f._lb._base = NULL;
   f._file = -1;  /* No file. */
   va_start (ap, fmt);
-  ret = __ssvfscanf_r (_REENT, &f, fmt, ap);
+  ret = _ssvfscanf ( &f, fmt, ap);
   va_end (ap);
   return ret;
 }
 
 #ifdef _NANO_FORMATTED_IO
-int
+int __nonnull((1)) _NOTHROW
 siscanf (const char *, const char *, ...)
        _ATTRIBUTE ((__alias__("sscanf")));
 #endif
-
-#endif /* !_REENT_ONLY */
-
-int 
-_sscanf_r (struct _reent *ptr,
-       const char *__restrict str,
-       const char *__restrict fmt, ...)
-{
-  int ret;
-  va_list ap;
-  FILE f;
-
-  f._flags = __SRD | __SSTR;
-  f._bf._base = f._p = (unsigned char *) str;
-  f._bf._size = f._r = strlen (str);
-  f._read = __seofread;
-  f._ub._base = NULL;
-  f._lb._base = NULL;
-  f._file = -1;  /* No file. */
-  va_start (ap, fmt);
-  ret = __ssvfscanf_r (ptr, &f, fmt, ap);
-  va_end (ap);
-  return ret;
-}
-
-#ifdef _NANO_FORMATTED_IO
-int
-_siscanf_r (struct _reent *, const char *, const char *, ...)
-       _ATTRIBUTE ((__alias__("_sscanf_r")));
-#endif
