@@ -13,7 +13,7 @@
 #include "local.h"
 
 int
-_vdprintf_r (struct _reent *ptr,
+vdprintf (
        int fd,
        const char *__restrict format,
        va_list ap)
@@ -23,7 +23,7 @@ _vdprintf_r (struct _reent *ptr,
   size_t n = sizeof buf;
 
   _REENT_SMALL_CHECK_INIT (ptr);
-  p = _vasnprintf_r (ptr, buf, &n, format, ap);
+  p = vasnprintf ( buf, &n, format, ap);
   if (!p)
     return -1;
   n = write (fd, p, n);
@@ -32,25 +32,8 @@ _vdprintf_r (struct _reent *ptr,
   return n;
 }
 
-#ifdef _NANO_FORMATTED_IO
-int
-_vdiprintf_r (struct _reent *, int, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("_vdprintf_r")));
-#endif
-
-#ifndef _REENT_ONLY
-
-int
-vdprintf (int fd,
-       const char *__restrict format,
-       va_list ap)
-{
-  return _vdprintf_r (_REENT, fd, format, ap);
-}
-
 #ifdef _NANO_FORMATTED_IO
 int
 vdiprintf (int, const char *, __VALIST)
        _ATTRIBUTE ((__alias__("vdprintf")));
 #endif
-#endif /* ! _REENT_ONLY */
