@@ -173,271 +173,24 @@ static char *rcsid = "$Id$";
 #endif
 
 #ifdef STRING_ONLY
+
 # ifdef _FVWRITE_IN_STREAMIO
-#  define __SPRINT _ssprint
+#  define __SPRINT __ssprint
+   int __ssprint (FILE *, register struct __suio *);
 # else
-#  define __SPRINT _ssputs
+#  define __SPRINT __ssputs
+   int __ssputs (FILE *, const char *, size_t);
 # endif
-#else
-# ifdef _FVWRITE_IN_STREAMIO
-#  define __SPRINT _sprint
-# else
-#  define __SPRINT _sfputs
-# endif
-#endif
-
-/* The __sprint_r/__ssprint_r functions are shared between all versions of
-   vfprintf and vfwprintf.  They must only be defined once, which we do in
-   the INTEGER_ONLY versions here. */
-#ifdef STRING_ONLY
-#ifdef INTEGER_ONLY
-#ifndef _FVWRITE_IN_STREAMIO
-int
-_ssputs (
-       FILE *fp,
-       const char *buf,
-       size_t len)
-{
-	register int w;
-
-	w = fp->_w;
-	if (len >= (size_t) w && fp->_flags & (__SMBF | __SOPT)) {
-		/* must be asprintf family */
-		unsigned char *str;
-		int curpos = (fp->_p - fp->_bf._base);
-		/* Choose a geometric growth factor to avoid
-	 	 * quadratic realloc behavior, but use a rate less
-		 * than (1+sqrt(5))/2 to accomodate malloc
-	 	 * overhead. asprintf EXPECTS us to overallocate, so
-	 	 * that it can add a trailing \0 without
-	 	 * reallocating.  The new allocation should thus be
-	 	 * max(prev_size*1.5, curpos+len+1). */
-		int newsize = fp->_bf._size * 3 / 2;
-		if ((size_t) newsize < curpos + len + 1)
-			newsize = curpos + len + 1;
-		if (fp->_flags & __SOPT)
-		{
-			/* asnprintf leaves original buffer alone.  */
-			str = (unsigned char *)malloc (newsize);
-			if (!str)
-			{
-				_REENT_ERRNO(ptr) = ENOMEM;
-				goto err;
-			}
-			memcpy (str, fp->_bf._base, curpos);
-			fp->_flags = (fp->_flags & ~__SOPT) | __SMBF;
-		}
-		else
-		{
-			str = (unsigned char *)realloc (fp->_bf._base,
-					newsize);
-			if (!str) {
-				/* Free unneeded buffer.  */
-				free (fp->_bf._base);
-				/* Ensure correct errno, even if free
-				 * changed it.  */
-				_REENT_ERRNO(ptr) = ENOMEM;
-				goto err;
-			}
-		}
-		fp->_bf._base = str;
-		fp->_p = str + curpos;
-		fp->_bf._size = newsize;
-		w = len;
-		fp->_w = newsize - curpos;
-	}
-	if (len < (size_t) w)
-		w = len;
-	(void)memmove ((void *) fp->_p, (void *) buf, (size_t) (w));
-	fp->_w -= w;
-	fp->_p += w;
-
-	return 0;
-
-err:
-	fp->_flags |= __SERR;
-	return EOF;
-}
-#endif
-
-int
-_ssprint (
-       FILE *fp,
-       register struct __suio *uio)
-{
-	register size_t len;
-	register int w;
-	register struct __siov *iov;
-	register const char *p = NULL;
-
-	iov = uio->uio_iov;
-	len = 0;
-
-	if (uio->uio_resid == 0) {
-		uio->uio_iovcnt = 0;
-		return (0);
-	}
-
-        do {
-		while (len == 0) {
-			p = iov->iov_base;
-			len = iov->iov_len;
-			iov++;
-		}
-		w = fp->_w;
-		if (len >= (size_t) w && fp->_flags & (__SMBF | __SOPT)) {
-			/* must be asprintf family */
-			unsigned char *str;
-			int curpos = (fp->_p - fp->_bf._base);
-			/* Choose a geometric growth factor to avoid
-		 	 * quadratic realloc behavior, but use a rate less
-			 * than (1+sqrt(5))/2 to accomodate malloc
-		 	 * overhead. asprintf EXPECTS us to overallocate, so
-		 	 * that it can add a trailing \0 without
-		 	 * reallocating.  The new allocation should thus be
-		 	 * max(prev_size*1.5, curpos+len+1). */
-			int newsize = fp->_bf._size * 3 / 2;
-			if ((size_t) newsize < curpos + len + 1)
-				newsize = curpos + len + 1;
-			if (fp->_flags & __SOPT)
-			{
-				/* asnprintf leaves original buffer alone.  */
-				str = (unsigned char *)malloc (newsize);
-				if (!str)
-				{
-					_REENT_ERRNO(ptr) = ENOMEM;
-					goto err;
-				}
-				memcpy (str, fp->_bf._base, curpos);
-				fp->_flags = (fp->_flags & ~__SOPT) | __SMBF;
-			}
-			else
-			{
-				str = (unsigned char *)realloc (fp->_bf._base,
-						newsize);
-				if (!str) {
-					/* Free unneeded buffer.  */
-					free (fp->_bf._base);
-					/* Ensure correct errno, even if free
-					 * changed it.  */
-					_REENT_ERRNO(ptr) = ENOMEM;
-					goto err;
-				}
-			}
-			fp->_bf._base = str;
-			fp->_p = str + curpos;
-			fp->_bf._size = newsize;
-			w = len;
-			fp->_w = newsize - curpos;
-		}
-		if (len < (size_t) w)
-			w = len;
-		(void)memmove ((void *) fp->_p, (void *) p, (size_t) (w));
-		fp->_w -= w;
-		fp->_p += w;
-		w = len;          /* pretend we copied all */
-		p += w;
-		len -= w;
-        } while ((uio->uio_resid -= w) != 0);
-
-	uio->uio_resid = 0;
-	uio->uio_iovcnt = 0;
-	return 0;
-
-err:
-  fp->_flags |= __SERR;
-  uio->uio_resid = 0;
-  uio->uio_iovcnt = 0;
-  return EOF;
-}
-#else /* !INTEGER_ONLY */
-#ifndef _FVWRITE_IN_STREAMIO
-int _ssputs ( FILE *, const char *, size_t);
-#endif
-int _ssprint ( FILE *, register struct __suio *);
-#endif /* !INTEGER_ONLY */
 
 #else /* !STRING_ONLY */
-#ifdef INTEGER_ONLY
 
-#ifndef _FVWRITE_IN_STREAMIO
-int
-_sfputs (
-       FILE *fp,
-       const char *buf,
-       size_t len)
-{
-	register int i;
-
-#if defined _WIDE_ORIENT && (!defined _ELIX_LEVEL || _ELIX_LEVEL >= 4)
-	if (fp->_flags2 & __SWID) {
-		wchar_t *p;
-
-		p = (wchar_t *) buf;
-		for (i = 0; i < (len / sizeof (wchar_t)); i++) {
-			if (fputwc ( p[i], fp) == WEOF)
-				return -1;
-		}
-	} else {
-#else
-	{
-#endif
-                for (i = 0; (size_t) i < len; i++) {
-			if (fputc ( buf[i], fp) == EOF)
-				return -1;
-		}
-	}
-	return (0);
-}
-#endif
-/*
- * Flush out all the vectors defined by the given uio,
- * then reset it so that it can be reused.
- */
-int
-_sprint (
-       FILE *fp,
-       register struct __suio *uio)
-{
-	register int err = 0;
-
-	if (uio->uio_resid == 0) {
-		uio->uio_iovcnt = 0;
-		return (0);
-	}
-#if defined _WIDE_ORIENT && (!defined _ELIX_LEVEL || _ELIX_LEVEL >= 4)
-	if (fp->_flags2 & __SWID) {
-		struct __siov *iov;
-		wchar_t *p;
-		int i, len;
-
-		iov = uio->uio_iov;
-		for (; uio->uio_resid != 0;
-		     uio->uio_resid -= len * sizeof (wchar_t), iov++) {
-			p = (wchar_t *) iov->iov_base;
-			len = iov->iov_len / sizeof (wchar_t);
-			for (i = 0; i < len; i++) {
-				if (fputwc ( p[i], fp) == WEOF) {
-					err = -1;
-					goto out;
-				}
-			}
-		}
-out:
-		;
-	} else
-#endif
-		err = _sfvwrite( fp, uio);
-	uio->uio_resid = 0;
-	uio->uio_iovcnt = 0;
-	return (err);
-}
-#else /* !INTEGER_ONLY */
-#ifndef _FVWRITE_IN_STREAMIO
-int _sfputs ( FILE *, const char *buf, size_t);
-#endif
-int _sprint ( FILE *, register struct __suio *);
-#endif /* !INTEGER_ONLY */
+# ifdef _FVWRITE_IN_STREAMIO
+#  define __SPRINT __sprint
+   int __sprint (FILE *, register struct __suio *);
+# else
+#  define __SPRINT __sfputs
+   int __sfputs (FILE *, const char *buf, size_t);
+# endif
 
 #ifdef _UNBUF_STREAM_OPT
 /*
@@ -448,7 +201,7 @@ int _sprint ( FILE *, register struct __suio *);
  * Make sure to avoid inlining.
  */
 _NOINLINE_STATIC int
-__sbprintf (struct _reent *rptr,
+__sbprintf (
        register FILE *fp,
        const char *fmt,
        va_list ap)
@@ -586,9 +339,13 @@ union arg_val
   wint_t val_wint_t;
 };
 
+typedef struct {
+    va_list ap;
+} my_va_list;
+
 static union arg_val *
-get_arg (struct _reent *data, int n, char *fmt,
-                 va_list *ap, int *numargs, union arg_val *args,
+get_arg (int n, char *fmt,
+                 my_va_list *ap, int *numargs, union arg_val *args,
                  int *arg_type, char **last_fmt);
 #endif /* !_NO_POS_ARGS */
 
@@ -643,6 +400,8 @@ VFPRINTF (
 	int arg_index;          /* index into args processed directly */
 	int numargs;            /* number of varargs read */
 	char *saved_fmt;        /* saved fmt pointer */
+        my_va_list my_ap;
+        va_copy(my_ap.ap, ap);
 	union arg_val args[MAX_POS_ARGS];
 	int arg_type[MAX_POS_ARGS];
 	int is_pos_arg;         /* is current format positional? */
@@ -779,13 +538,13 @@ VFPRINTF (
 	(is_pos_arg							\
 	 ? (n < numargs							\
 	    ? args[n].val_##type					\
-	    : get_arg (data, n, fmt_anchor, &ap, &numargs, args,	\
+	    : get_arg (n, fmt_anchor, &my_ap, &numargs, args,     \
 		       arg_type, &saved_fmt)->val_##type)		\
 	 : (arg_index++ < numargs					\
 	    ? args[n].val_##type					\
 	    : (numargs < MAX_POS_ARGS					\
-	       ? args[numargs++].val_##type = va_arg (ap, type)		\
-	       : va_arg (ap, type))))
+	       ? args[numargs++].val_##type = va_arg (my_ap.ap, type)		\
+	       : va_arg (my_ap.ap, type))))
 #else
 # define GET_ARG(n, ap, type) (va_arg (ap, type))
 #endif
@@ -801,31 +560,51 @@ VFPRINTF (
 	    flags&SHORTINT ? (long)(short)GET_ARG (N, ap, int) : \
 	    flags&CHARINT ? (long)(signed char)GET_ARG (N, ap, int) : \
 	    (long)GET_ARG (N, ap, int))
+#ifdef __MSP430__
+#define	UARG() \
+	(flags&QUADINT ? GET_ARG (N, ap, u_quad_t) : \
+	    flags&LONGINT ? GET_ARG (N, ap, u_long) : \
+	    flags&SHORTINT ? (u_long)(u_short)GET_ARG (N, ap, int) : \
+	    flags&CHARINT ? (u_long)(GET_ARG (N, ap, int) & 0xff) : \
+	    (u_long)GET_ARG (N, ap, u_int))
+#else
 #define	UARG() \
 	(flags&QUADINT ? GET_ARG (N, ap, u_quad_t) : \
 	    flags&LONGINT ? GET_ARG (N, ap, u_long) : \
 	    flags&SHORTINT ? (u_long)(u_short)GET_ARG (N, ap, int) : \
 	    flags&CHARINT ? (u_long)(unsigned char)GET_ARG (N, ap, int) : \
 	    (u_long)GET_ARG (N, ap, u_int))
+#endif
 #else
 #define	SARG() \
 	(flags&LONGINT ? GET_ARG (N, ap, long) : \
 	    flags&SHORTINT ? (long)(short)GET_ARG (N, ap, int) : \
 	    flags&CHARINT ? (long)(signed char)GET_ARG (N, ap, int) : \
 	    (long)GET_ARG (N, ap, int))
+#ifdef __MSP430__
+#define	UARG() \
+	(flags&LONGINT ? GET_ARG (N, ap, u_long) : \
+	    flags&SHORTINT ? (u_long)(u_short)GET_ARG (N, ap, int) : \
+	    flags&CHARINT ? (u_long)(GET_ARG (N, ap, int) & 0xff) :     \
+	    (u_long)GET_ARG (N, ap, u_int))
+#else
 #define	UARG() \
 	(flags&LONGINT ? GET_ARG (N, ap, u_long) : \
 	    flags&SHORTINT ? (u_long)(u_short)GET_ARG (N, ap, int) : \
 	    flags&CHARINT ? (u_long)(unsigned char)GET_ARG (N, ap, int) : \
 	    (u_long)GET_ARG (N, ap, u_int))
 #endif
+#endif
 
 #ifndef STRING_ONLY
 	/* Initialize std streams if not dealing with sprintf family.  */
 	CHECK_INIT (data, fp);
 	_newlib_flockfile_start (fp);
 
-	ORIENT(fp, -1);
+	if (ORIENT(fp, -1) != -1) {
+		_newlib_flockfile_exit (fp);
+		return (EOF);
+	}
 
 	/* sorry, fprintf(read_only_file, "") returns EOF, not 0 */
 	if (cantwrite (data, fp)) {
@@ -838,7 +617,7 @@ VFPRINTF (
 	if ((fp->_flags & (__SNBF|__SWR|__SRW)) == (__SNBF|__SWR) &&
 	    fp->_file >= 0) {
 		_newlib_flockfile_exit (fp);
-		return (__sbprintf (data, fp, fmt0, ap));
+		return (__sbprintf (fp, fmt0, ap));
 	}
 #endif
 #else /* STRING_ONLY */
@@ -990,7 +769,7 @@ reswitch:	switch (ch) {
 			if (width >= 0)
 				goto rflag;
 			width = -width;
-			FALLTHROUGH;
+			__PICOLIBC_FALLTHROUGH;
 		case '-':
 			flags |= LADJUST;
 			goto rflag;
@@ -1161,7 +940,7 @@ reswitch:	switch (ch) {
 			break;
 		case 'D':  /* extension */
 			flags |= LONGINT;
-			FALLTHROUGH;
+			__PICOLIBC_FALLTHROUGH;
 		case 'd':
 		case 'i':
 			_uquad = SARG ();
@@ -1382,7 +1161,7 @@ reswitch:	switch (ch) {
 			continue;	/* no output */
 		case 'O': /* extension */
 			flags |= LONGINT;
-			FALLTHROUGH;
+			__PICOLIBC_FALLTHROUGH;
 		case 'o':
 			_uquad = UARG ();
 			base = OCT;
@@ -1477,7 +1256,7 @@ string:
 
 				/* Convert widechar string to multibyte string. */
 				memset ((void *)&ps, '\0', sizeof (mbstate_t));
-				if (wcsrtombs (cp, &wcp, size, &ps)
+				if ((int)wcsrtombs (cp, &wcp, size, &ps)
 				    != size) {
 					fp->_flags |= __SERR;
 					goto error;
@@ -1504,7 +1283,7 @@ string:
 			break;
 		case 'U': /* extension */
 			flags |= LONGINT;
-			FALLTHROUGH;
+			__PICOLIBC_FALLTHROUGH;
 		case 'u':
 			_uquad = UARG ();
 			base = DEC;
@@ -2012,10 +1791,10 @@ const __ACTION __action_table[MAX_STATE][MAX_CH_CLASS] = {
 
 /* function to get positional parameter N where n = N - 1 */
 static union arg_val *
-get_arg (struct _reent *data,
+get_arg (
        int n,
        char *fmt,
-       va_list *ap,
+       my_va_list *ap,
        int *numargs_p,
        union arg_val *args,
        int *arg_type,
@@ -2221,25 +2000,25 @@ get_arg (struct _reent *data,
 		    switch (spec_type)
 		      {
 		      case LONG_INT:
-			args[numargs++].val_long = va_arg (*ap, long);
+			args[numargs++].val_long = va_arg (ap->ap, long);
 			break;
 		      case QUAD_INT:
-			args[numargs++].val_quad_t = va_arg (*ap, quad_t);
+			args[numargs++].val_quad_t = va_arg (ap->ap, quad_t);
 			break;
 		      case WIDE_CHAR:
-			args[numargs++].val_wint_t = va_arg (*ap, wint_t);
+			args[numargs++].val_wint_t = va_arg (ap->ap, wint_t);
 			break;
 		      case INT:
-			args[numargs++].val_int = va_arg (*ap, int);
+			args[numargs++].val_int = va_arg (ap->ap, int);
 			break;
 		      case CHAR_PTR:
-			args[numargs++].val_char_ptr_t = va_arg (*ap, char *);
+			args[numargs++].val_char_ptr_t = va_arg (ap->ap, char *);
 			break;
 		      case DOUBLE:
-			args[numargs++].val_double = va_arg (*ap, double);
+			args[numargs++].val_double = va_arg (ap->ap, double);
 			break;
 		      case LONG_DOUBLE:
-			args[numargs++].val__LONG_DOUBLE = va_arg (*ap, _LONG_DOUBLE);
+			args[numargs++].val__LONG_DOUBLE = va_arg (ap->ap, _LONG_DOUBLE);
 			break;
 		      }
 		  }
@@ -2260,9 +2039,9 @@ get_arg (struct _reent *data,
 	      break;
 	    case GETPWB: /* we require format pushback */
 	      --fmt;
-	      FALLTHROUGH;
+	      __PICOLIBC_FALLTHROUGH;
 	    case GETPW:  /* we have a variable precision or width to acquire */
-	      args[numargs++].val_int = va_arg (*ap, int);
+	      args[numargs++].val_int = va_arg (ap->ap, int);
 	      break;
 	    case NUMBER: /* we have a number to process */
 	      number = (ch - '0');
@@ -2295,26 +2074,26 @@ get_arg (struct _reent *data,
       switch (arg_type[numargs])
 	{
 	case LONG_INT:
-	  args[numargs++].val_long = va_arg (*ap, long);
+	  args[numargs++].val_long = va_arg (ap->ap, long);
 	  break;
 	case QUAD_INT:
-	  args[numargs++].val_quad_t = va_arg (*ap, quad_t);
+	  args[numargs++].val_quad_t = va_arg (ap->ap, quad_t);
 	  break;
 	case CHAR_PTR:
-	  args[numargs++].val_char_ptr_t = va_arg (*ap, char *);
+	  args[numargs++].val_char_ptr_t = va_arg (ap->ap, char *);
 	  break;
 	case DOUBLE:
-	  args[numargs++].val_double = va_arg (*ap, double);
+	  args[numargs++].val_double = va_arg (ap->ap, double);
 	  break;
 	case LONG_DOUBLE:
-	  args[numargs++].val__LONG_DOUBLE = va_arg (*ap, _LONG_DOUBLE);
+	  args[numargs++].val__LONG_DOUBLE = va_arg (ap->ap, _LONG_DOUBLE);
 	  break;
 	case WIDE_CHAR:
-	  args[numargs++].val_wint_t = va_arg (*ap, wint_t);
+	  args[numargs++].val_wint_t = va_arg (ap->ap, wint_t);
 	  break;
 	case INT:
 	default:
-	  args[numargs++].val_int = va_arg (*ap, int);
+	  args[numargs++].val_char_ptr_t = va_arg (ap->ap, char *);
 	  break;
 	}
     }
