@@ -166,7 +166,11 @@ C99, POSIX-1.2008
 #  define MAX_POS_ARGS 32
 # endif
 
-static void * get_arg (int, va_list *, int *, void **);
+typedef struct {
+    va_list ap;
+} my_va_list;
+
+static void * get_arg (int, my_va_list *, int *, void **);
 #endif /* _WANT_IO_POS_ARGS */
 
 /*
@@ -292,6 +296,8 @@ _SVFWSCANF (
   int N;			/* arg number */
   int arg_index = 0;		/* index into args processed directly */
   int numargs = 0;		/* number of varargs read */
+  my_va_list my_ap;
+  va_copy(my_ap.ap, ap);
   void *args[MAX_POS_ARGS];	/* positional args read */
   int is_pos_arg;		/* is current format positional? */
 #endif
@@ -455,12 +461,12 @@ _SVFWSCANF (
   ((type) (is_pos_arg						\
 	   ? (n < numargs					\
 	      ? args[n]						\
-	      : get_arg (n, &ap, &numargs, args))		\
+	      : get_arg (n, &my_ap, &numargs, args))      \
 	   : (arg_index++ < numargs				\
 	      ? args[n]						\
 	      : (numargs < MAX_POS_ARGS				\
-		 ? args[numargs++] = va_arg (ap, void *)	\
-		 : va_arg (ap, void *)))))
+		 ? args[numargs++] = va_arg (my_ap.ap, void *)	\
+		 : va_arg (my_ap.ap, void *)))))
 #else
 # define GET_ARG(n, ap, type) (va_arg (ap, type))
 #endif
@@ -488,7 +494,11 @@ _SVFWSCANF (
 
   _newlib_flockfile_start (fp);
 
-  ORIENT (fp, 1);
+  if (ORIENT (fp, 1) != 1)
+    {
+      nassigned = EOF;
+      goto all_done;
+    }
 
   nassigned = 0;
   nread = 0;
@@ -708,7 +718,7 @@ _SVFWSCANF (
 #ifdef _WANT_IO_C99_FORMATS
 	case L'S':
 	  flags |= LONG;
-          FALLTHROUGH;
+          __PICOLIBC_FALLTHROUGH;
 #endif
 
 	case L's':
@@ -737,7 +747,7 @@ _SVFWSCANF (
 #ifdef _WANT_IO_C99_FORMATS
 	case 'C':
 	  flags |= LONG;
-          FALLTHROUGH;
+          __PICOLIBC_FALLTHROUGH;
 #endif
 
 	case 'c':
@@ -1607,11 +1617,11 @@ all_done:
    intermediate arguments are sizeof(void*), so we don't need to scan
    ahead in the format string.  */
 static void *
-get_arg (int n, va_list *ap, int *numargs_p, void **args)
+get_arg (int n, my_va_list *my_ap, int *numargs_p, void **args)
 {
   int numargs = *numargs_p;
   while (n >= numargs)
-    args[numargs++] = va_arg (*ap, void *);
+    args[numargs++] = va_arg (my_ap->ap, void *);
   *numargs_p = numargs;
   return args[n];
 }
