@@ -76,7 +76,7 @@ Supporting OS subroutines required: <<close>>, <<fstat>>, <<isatty>>,
 #ifdef __LARGE64_FILES
 
 FILE *
-_freopen64_r (struct _reent *ptr,
+freopen64 (
 	const char *file,
 	const char *mode,
 	register FILE *fp)
@@ -98,14 +98,14 @@ _freopen64_r (struct _reent *ptr,
   if (!(oflags2 & __SNLK))
     _flockfile (fp);
 
-  if ((flags = __sflags (ptr, mode, &oflags)) == 0)
+  if ((flags = __sflags (mode, &oflags)) == 0)
     {
       if (!(oflags2 & __SNLK))
 	_funlockfile (fp);
 #ifdef _STDIO_WITH_THREAD_CANCELLATION_SUPPORT
       pthread_setcancelstate (__oldcancel, &__oldcancel);
 #endif
-      _fclose_r (ptr, fp);
+      fclose (fp);
       return NULL;
     }
 
@@ -122,13 +122,13 @@ _freopen64_r (struct _reent *ptr,
   else
     {
       if (fp->_flags & __SWR)
-	_fflush_r (ptr, fp);
+	fflush (fp);
       /*
        * If close is NULL, closing is a no-op, hence pointless.
        * If file is NULL, the file should not be closed.
        */
       if (fp->_close != NULL && file != NULL)
-	fp->_close (ptr, fp->_cookie);
+	fp->_close (fp->_cookie);
     }
 
   /*
@@ -139,11 +139,11 @@ _freopen64_r (struct _reent *ptr,
   if (file != NULL)
     {
       f = open64 ((char *) file, oflags, 0666);
-      e = __errno_r(ptr);
+      e = _REENT_ERRNO(ptr);
     }
   else
     {
-#ifdef HAVE_FCNTL
+#ifdef _HAVE_FCNTL
       int oldflags;
       /*
        * Reuse the file descriptor, but only if the new access mode is
@@ -174,7 +174,7 @@ _freopen64_r (struct _reent *ptr,
 	{
 	  e = EBADF;
 	  if (fp->_close != NULL)
-	    fp->_close (ptr, fp->_cookie);
+	    fp->_close (fp->_cookie);
 	}
     }
 
@@ -207,7 +207,7 @@ _freopen64_r (struct _reent *ptr,
     {				/* did not get it after all */
       __sfp_lock_acquire ();
       fp->_flags = 0;		/* set it free */
-      __errno_r(ptr) = e;		/* restore in case _close clobbered */
+      _REENT_ERRNO(ptr) = e;	/* restore in case _close clobbered */
       if (!(oflags2 & __SNLK))
 	_funlockfile (fp);
 #ifndef __SINGLE_THREAD__
@@ -244,16 +244,4 @@ _freopen64_r (struct _reent *ptr,
   return fp;
 }
 
-#ifndef _REENT_ONLY
-
-FILE *
-freopen64 (const char *file,
-	const char *mode,
-	register FILE *fp)
-{
-  return _freopen64_r (_REENT, file, mode, fp);
-}
-
-#endif /* !_REENT_ONLY */
-
 #endif /* __LARGE64_FILES */
