@@ -26,6 +26,7 @@
 	dmg@research.att.com or research!dmg
  */
 
+#define _DEFAULT_SOURCE
 #include <_ansi.h>
 #include <stdlib.h>
 #include <string.h>
@@ -398,7 +399,7 @@ __dtoa (
       break;
     case 2:
       leftright = 0;
-      /* no break */
+      __PICOLIBC_FALLTHROUGH;
     case 4:
       if (ndigits <= 0)
 	ndigits = 1;
@@ -406,7 +407,7 @@ __dtoa (
       break;
     case 3:
       leftright = 0;
-      /* no break */
+      __PICOLIBC_FALLTHROUGH;
     case 5:
       i = ndigits + k + 1;
       ilim = i;
