@@ -276,6 +276,12 @@ fcvtbuf (double invalue,
   if (!p)
     return NULL;
 
+  if (*decpt == 9999)
+    {
+      strcpy(fcvt_buf, p);
+      return fcvt_buf;
+    }
+
   /* Now copy */
 
   done = -*decpt;
@@ -327,6 +333,12 @@ ecvtbuf (double invalue,
   if (!p)
     return NULL;
 
+  if (*decpt == 9999)
+    {
+      strcpy(fcvt_buf, p);
+      return fcvt_buf;
+    }
+
   /* Now copy */
 
   while (p < end)
