@@ -9,6 +9,7 @@ All rights reserved.
 #include <wchar.h>
 #include <string.h>
 #include <errno.h>
+#include <stdint.h>
 #include "local.h"
 
 int
@@ -31,14 +32,6 @@ __ascii_mbtowc (
   if (n == 0)
     return -2;
 
-#ifdef __CYGWIN__
-  if ((wchar_t)*t >= 0x80)
-    {
-      _REENT_ERRNO(r) = EILSEQ;
-      return -1;
-    }
-#endif
-
   *pwc = (wchar_t)*t;
   
   if (*t == '\0')
