@@ -403,6 +403,12 @@ __strong_reference(malloc, __malloc_malloc);
 
 #ifdef DEFINE_FREE
 
+#ifdef __GNUC__
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wunknown-warning-option"
+#pragma GCC diagnostic ignored "-Wanalyzer-null-dereference"
+#endif
+
 /** Function free
   * Implementation of libc free.
   * Algorithm:
@@ -649,7 +655,7 @@ struct mallinfo mallinfo(void)
     size_t free_size = 0;
     size_t total_size;
     size_t ordblks = 0;
-    struct mallinfo current_mallinfo;
+    struct mallinfo current_mallinfo = {};
 
     MALLOC_LOCK;
 
