@@ -7,6 +7,7 @@ All rights reserved.
 #include <string.h>
 #include <wchar.h>
 #include <locale.h>
+#include <stdint.h>
 #include "mbctype.h"
 #include "local.h"
 
@@ -25,11 +26,7 @@ __ascii_wctomb (
   if (s == NULL)
     return 0;
  
-#ifdef __CYGWIN__
-  if ((size_t)wchar >= 0x80)
-#else
   if ((size_t)wchar >= 0x100)
-#endif
     {
       _REENT_ERRNO(r) = EILSEQ;
       return -1;
