@@ -1,6 +1,6 @@
 /* Copyright (c) 2009 Corinna Vinschen <corinna@vinschen.de> */
 #include <_ansi.h>
-#include <../ctype/local.h>
+#include "../ctype/local.h"
 
 /* internal function to compute width of wide char. */
 int __wcwidth (wint_t);
