@@ -33,7 +33,7 @@ asctime_r (const struct tm *__restrict tim_p,
 	"Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
   };
 
-  __i_sprintf (result, "%.3s %.3s%3d %.2d:%.2d:%.2d %d\n",
+  sprintf (result, "%.3s %.3s%3d %.2d:%.2d:%.2d %d\n",
 	    day_name[tim_p->tm_wday], 
 	    mon_name[tim_p->tm_mon],
 	    tim_p->tm_mday, tim_p->tm_hour, tim_p->tm_min,
