@@ -9,7 +9,7 @@
 
 #include "local.h"
 
-const int __month_lengths[2][MONSPERYEAR] = {
+const uint8_t __month_lengths[2][MONSPERYEAR] = {
   {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31},
   {31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}
 } ;
