@@ -30,57 +30,34 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "scanf_private.h"
-#include "../../libm/common/math_config.h"
-
 static const char pstr_nfinity[] = "nfinity";
 static const char pstr_an[] = "an";
 
 #if defined(STRTOD) || defined(STRTOF) || defined(STRTOLD)
 # define CHECK_WIDTH()   1
 # define CHECK_RANGE(flt) do {                                          \
-        if (CHECK_LONG()) {                                             \
-            if ((double) flt == 0.0 || (double) flt == (double) INFINITY) \
-                errno = ERANGE;                                         \
-        } else if (CHECK_LONG_LONG()) {                                 \
-            if (flt == (FLOAT) 0.0 || flt == (FLOAT) INFINITY)          \
-                errno = ERANGE;                                         \
-        } else {                                                        \
-            if ((float) flt == 0.0f || (float) flt == (float) INFINITY) \
-                errno = ERANGE;                                         \
-        }                                                               \
+        int __class = fpclassify(flt);                                  \
+        if (__class == FP_INFINITE || __class == FP_SUBNORMAL || __class == FP_ZERO) \
+            errno = ERANGE;                                             \
     } while (0);
-# ifdef STRTOD
+# ifdef _WANT_IO_C99_FORMATS
+#  define _NEED_IO_C99_FORMATS
+# endif
+# if defined(STRTOD)
+#  define _NEED_IO_DOUBLE
+#  define SCANF_LEVEL           SCANF_DBL
 #  define CHECK_LONG()          1
 #  define CHECK_LONG_LONG()     0
-#  define FLOAT_MIN             __DBL_MIN__
-#  define FLOAT_MANT_DIG        __DBL_MANT_DIG__
-#  define FLOAT_MAX_EXP         __DBL_MAX_EXP__
-#  define FLOAT_MIN_EXP         __DBL_MIN_EXP__
-#  define ASFLOAT(x)            _asdouble(x)
-#  define TOFLOAT(x)            ((double) (x))
 # elif defined(STRTOLD)
+#  define _NEED_IO_LONG_DOUBLE
+#  define SCANF_LEVEL           SCANF_DBL
 #  define CHECK_LONG()          0
 #  define CHECK_LONG_LONG()     1
-#  define FLOAT_MIN             __LDBL_MIN__
-#  define FLOAT_MANT_DIG        __LDBL_MANT_DIG__
-#  define FLOAT_MAX_EXP         __LDBL_MAX_EXP__
-#  define FLOAT_MIN_EXP         __LDBL_MIN_EXP__
-#  define ASFLOAT(x)            aslongdouble(x)
-#  define TOFLOAT(x)            _u128_to_ld(x)
-typedef long double FLOAT;
-typedef _u128 UINTFLOAT;
-#define UINTFLOAT_128
-# else
+# elif defined(STRTOF)
+#  define _NEED_IO_FLOAT
+#  define SCANF_LEVEL           SCANF_FLT
 #  define CHECK_LONG()          0
 #  define CHECK_LONG_LONG()     0
-#  define PICOLIBC_FLOAT_PRINTF_SCANF
-#  define FLOAT_MIN             __FLT_MIN__
-#  define FLOAT_MANT_DIG        __FLT_MANT_DIG__
-#  define FLOAT_MAX_EXP         __FLT_MAX_EXP__
-#  define FLOAT_MIN_EXP         __FLT_MIN_EXP__
-#  define ASFLOAT(x)            _asfloat(x)
-#  define TOFLOAT(x)            ((float) (x))
 # endif
 
 #define FLT_STREAM const char
@@ -104,49 +81,76 @@ static inline void scanf_ungetc(int c, const char *s, int *lenp)
 #define EOF -1
 
 #else
+
 # define CHECK_WIDTH()   (--width != 0)
 # define CHECK_RANGE(flt)
-# ifdef PICOLIBC_FLOAT_PRINTF_SCANF
-#  define CHECK_LONG()    0
+
+# ifdef _NEED_IO_FLOAT
+
+#  define CHECK_LONG()          0
 #  define CHECK_LONG_LONG()     0
-#  define FLOAT_MANT_DIG        __FLT_MANT_DIG__
-#  define FLOAT_MAX_EXP         __FLT_MAX_EXP__
-#  define FLOAT_MIN_EXP         __FLT_MIN_EXP__
-#  define ASFLOAT(x) _asfloat(x)
-#  define TOFLOAT(x) ((float) (x))
-# else
-#  if __SIZEOF_LONG_DOUBLE__ == __SIZEOF_DOUBLE__
+
+# elif defined(_NEED_IO_DOUBLE)
+
+#  ifdef _NEED_IO_LONG_DOUBLE
+#   define CHECK_LONG()         (flags & FL_LONG)
+#   define CHECK_LONG_LONG()    (flags & FL_LONGLONG)
+#  else
 #   define CHECK_LONG()         (flags & (FL_LONG|FL_LONGLONG))
 #   define CHECK_LONG_LONG()    0
-#  else
-#   define CHECK_LONG()    (flags & FL_LONG)
-#   if defined(_WANT_IO_LONG_DOUBLE)
-#    define CHECK_LONG_LONG()     (flags & FL_LONGLONG)
-#    define FLOAT_MANT_DIG        __LDBL_MANT_DIG__
-#    define FLOAT_MAX_EXP         __LDBL_MAX_EXP__
-#    define FLOAT_MIN_EXP         __LDBL_MIN_EXP__
-#    define UINTFLOAT_128
-
-typedef long double FLOAT;
-typedef _u128 UINTFLOAT;
-
-#    define ASFLOAT(x) aslongdouble(x)
-#    define TOFLOAT(x) _u128_to_ld(x)
-#   else
-#    define CHECK_LONG_LONG()     0
-#   endif
-#  endif
-#  if __SIZEOF_LONG_DOUBLE__ == __SIZEOF_DOUBLE__ || !defined(_WANT_IO_LONG_DOUBLE)
-#   define FLOAT_MANT_DIG        __DBL_MANT_DIG__
-#   define FLOAT_MAX_EXP         __DBL_MAX_EXP__
-#   define FLOAT_MIN_EXP         __DBL_MIN_EXP__
-#   define ASFLOAT(x) _asdouble(x)
-#   define TOFLOAT(x) ((double) (x))
 #  endif
+# else
+#  define CHECK_LONG()          0
+#  define CHECK_LONG_LONG()     0
 # endif
 #endif
 
-#ifdef UINTFLOAT_128
+#include "scanf_private.h"
+
+#include "dtoa.h"
+
+#ifdef _NEED_IO_LONG_DOUBLE
+# define FLOAT                  long double
+# define FLOAT_MIN              __LDBL_MIN__
+# define FLOAT_MANT_DIG         __LDBL_MANT_DIG__
+# define FLOAT_MAX_EXP          __LDBL_MAX_EXP__
+# define FLOAT_MIN_EXP          __LDBL_MIN_EXP__
+# define ASFLOAT(x)             aslongdouble(x)
+# if __SIZEOF_LONG_DOUBLE__ > 8
+#  define TOFLOAT(x)            _u128_to_ld(x)
+#  define UINTFLOAT             _u128
+# elif __SIZEOF_LONG_DOUBLE__ == 8
+#  define TOFLOAT(x)            ((long double) (x))
+#  define UINTFLOAT             uint64_t
+# elif __SIZEOF_LONG_DOUBLE__ == 4
+#  define TOFLOAT(x)            ((long double) (x))
+#  define UINTFLOAT             uint32_t
+# endif
+#elif defined(_NEED_IO_DOUBLE)
+# define FLOAT                  double
+# define FLOAT_MIN              __DBL_MIN__
+# define FLOAT_MANT_DIG         __DBL_MANT_DIG__
+# define FLOAT_MAX_EXP          __DBL_MAX_EXP__
+# define FLOAT_MIN_EXP          __DBL_MIN_EXP__
+# define ASFLOAT(x)             _asdouble(x)
+# define TOFLOAT(x)             ((double) (x))
+# if __SIZEOF_DOUBLE__ == 4
+#  define UINTFLOAT             uint32_t
+# elif __SIZEOF_DOUBLE__ == 8
+#  define UINTFLOAT             uint64_t
+# endif
+#elif defined(_NEED_IO_FLOAT)
+# define FLOAT                  float
+# define FLOAT_MIN              __FLT_MIN__
+# define FLOAT_MANT_DIG         __FLT_MANT_DIG__
+# define FLOAT_MAX_EXP          __FLT_MAX_EXP__
+# define FLOAT_MIN_EXP          __FLT_MIN_EXP__
+# define ASFLOAT(x)             _asfloat(x)
+# define TOFLOAT(x)             ((float) (x))
+# define UINTFLOAT              uint32_t
+#endif
+
+#if FLOAT_MANT_DIG > 53
 #define U32_TO_UF(x)    to_u128(x)
 #define U64_TO_UF(x)    to_u128(x)
 #define U128_TO_UF(x)   (x)
@@ -188,10 +192,6 @@ typedef _u128 UINTFLOAT;
 #define UF_OR(a,b)              ((a) | (b))
 #endif
 
-#ifndef UINTFLOAT_128
-#include "dtoa_engine.h"
-#endif
-
 static unsigned char
 conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t flags)
 {
@@ -208,7 +208,7 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
     switch ((unsigned char)i) {
     case '-':
         flags |= FL_MINUS;
-	FALLTHROUGH;
+	__PICOLIBC_FALLTHROUGH;
     case '+':
 	if (!CHECK_WIDTH() || (i = scanf_getc (stream, lenp)) < 0)
 	    return 0;
@@ -230,7 +230,7 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
 	    while ((c = *p++) != 0) {
 		if (CHECK_WIDTH()) {
                     if ((i = scanf_getc (stream, lenp)) >= 0) {
-                        if ((unsigned char)TOLOWER(i) == c)
+                        if (TOLOWER(i) == c)
                             continue;
                         scanf_ungetc (i, stream, lenp);
                     }
@@ -246,13 +246,26 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
         exp = 0;
 	uint = U32_TO_UF(0);
 #define uintdigitsmax_10_float  8
-#define uintdigitsmax_10_double 16
-#define uintdigitsmax_10_long_double    32
 #define uintdigitsmax_16_float  7
+#if __SIZEOF_DOUBLE__ == 8
+#define uintdigitsmax_10_double 16
 #define uintdigitsmax_16_double 15
+#elif __SIZEOF_DOUBLE__ ==4
+#define uintdigitsmax_10_double 8
+#define uintdigitsmax_16_double 7
+#endif
+#if __SIZEOF_LONG_DOUBLE__ > 8
+#define uintdigitsmax_10_long_double    32
 #define uintdigitsmax_16_long_double    30
+#elif __SIZEOF_LONG_DOUBLE__ == 8
+#define uintdigitsmax_10_long_double    16
+#define uintdigitsmax_16_long_double    15
+#elif __SIZEOF_LONG_DOUBLE__ == 4
+#define uintdigitsmax_10_long_double    8
+#define uintdigitsmax_16_long_double    7
+#endif
 
-#ifdef _WANT_IO_C99_FORMATS
+#ifdef _NEED_IO_C99_FORMATS
         int base = 10;
 #else
 #define base 10
@@ -260,20 +273,20 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
 
 #define uintdigitsmax                                                   \
         ((base) == 10 ?                                                 \
-            (CHECK_LONG() ?                                             \
-             uintdigitsmax_10_double :                                  \
-             (CHECK_LONG_LONG() ? uintdigitsmax_10_long_double :        \
+            (CHECK_LONG_LONG() ? uintdigitsmax_10_long_double :         \
+             (CHECK_LONG() ?                                            \
+              uintdigitsmax_10_double :                                 \
               uintdigitsmax_10_float)) :                                \
-            (CHECK_LONG() ?                                             \
-             uintdigitsmax_16_double :                                  \
-             (CHECK_LONG_LONG() ? uintdigitsmax_16_long_double :        \
+            (CHECK_LONG_LONG() ? uintdigitsmax_16_long_double :         \
+             (CHECK_LONG() ?                                            \
+              uintdigitsmax_16_double :                                 \
               uintdigitsmax_16_float)))
 
 	do {
 
 	    unsigned char c;
 
-#ifdef _WANT_IO_C99_FORMATS
+#ifdef _NEED_IO_C99_FORMATS
             if ((flags & FL_FHEX) && (c = TOLOWER(i) - 'a') <= 5)
                 c += 10;
             else
@@ -299,7 +312,7 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
 
 	    } else if (c == (('.'-'0') & 0xff) && !(flags & FL_DOT)) {
 		flags |= FL_DOT;
-#ifdef _WANT_IO_C99_FORMATS
+#ifdef _NEED_IO_C99_FORMATS
             } else if (TOLOWER(i) == 'x' && (flags & FL_ANY) && UF_IS_ZERO(uint)) {
                 flags |= FL_FHEX;
                 base = 16;
@@ -312,7 +325,7 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
 	if (!(flags & FL_ANY))
 	    return 0;
 
-#ifdef _WANT_IO_C99_FORMATS
+#ifdef _NEED_IO_C99_FORMATS
         int exp_match = (flags & FL_FHEX) ? 'p' : 'e';
 #else
 #define exp_match 'e'
@@ -330,7 +343,7 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
 	    switch ((unsigned char)esign) {
             case '-':
 		flags |= FL_MEXP;
-		FALLTHROUGH;
+		__PICOLIBC_FALLTHROUGH;
             case '+':
                 if (!CHECK_WIDTH()) {
                     scanf_ungetc(esign, stream, lenp);
@@ -344,7 +357,7 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
                 break;
 	    }
 
-	    if (!ISDIGIT (edig))
+	    if (!isdigit (edig))
             {
                 scanf_ungetc(edig, stream, lenp);
                 if (esign != EOF)
@@ -358,10 +371,10 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
 	    do {
                 if (expacc < MAX_POSSIBLE_EXP)
                     expacc = expacc * 10 + (i - '0');
-	    } while (CHECK_WIDTH() && ISDIGIT (i = scanf_getc(stream, lenp)));
+	    } while (CHECK_WIDTH() && isdigit (i = scanf_getc(stream, lenp)));
 	    if (flags & FL_MEXP)
 		expacc = -expacc;
-#ifdef _WANT_IO_C99_FORMATS
+#ifdef _NEED_IO_C99_FORMATS
             if (flags & FL_FHEX)
                 exp *= 4;
 #endif
@@ -377,18 +390,18 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
 	    break;
 	}
 
-#ifdef _WANT_IO_C99_FORMATS
+#ifdef _NEED_IO_C99_FORMATS
         if (flags & FL_FHEX)
         {
             int sig_bits;
             int min_exp;
 
-            if (CHECK_LONG()) {
-                sig_bits = __DBL_MANT_DIG__;
-                min_exp = __DBL_MIN_EXP__ - 1;
-            } else if (CHECK_LONG_LONG()) {
+            if (CHECK_LONG_LONG()) {
                 sig_bits = __LDBL_MANT_DIG__;
                 min_exp = __LDBL_MIN_EXP__ - 1;
+            } else if (CHECK_LONG()) {
+                sig_bits = __DBL_MANT_DIG__;
+                min_exp = __DBL_MIN_EXP__ - 1;
             } else {
                 sig_bits = __FLT_MANT_DIG__;
                 min_exp = __FLT_MIN_EXP__ - 1;
@@ -448,12 +461,12 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
             if (exp >= FLOAT_MAX_EXP) {
                 flt = (FLOAT) INFINITY;
             } else {
-#if !defined(UINTFLOAT_128) || __LDBL_IS_IEC_60559__ != 0
+#if FLOAT_MANT_DIG <= 53 || __LDBL_IS_IEC_60559__ != 0 || defined(__m68k__)
                 if (UF_LT(uint, UF_LSHIFT_64(1, (FLOAT_MANT_DIG-1)))) {
                     exp = 0;
                 } else {
                     exp += (FLOAT_MAX_EXP - 1);
-#if defined(UINTFLOAT_128) && (defined(__x86_64__) || defined(__i386__))
+#if FLOAT_MANT_DIG > 53 && (defined(__x86_64__) || defined(__i386__))
                     /*
                      * Intel 80-bit format is weird -- there's an
                      * integer bit so denorms can have the 'real'
@@ -461,6 +474,8 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
                      * the integer bit
                      */
 #define EXP_SHIFT       FLOAT_MANT_DIG
+#elif FLOAT_MANT_DIG > 53 && defined(__m68k__)
+#define EXP_SHIFT   FLOAT_MANT_DIG + 16
 #else
                     uint = UF_AND(uint, UF_NOT(UF_LSHIFT_64(1, (FLOAT_MANT_DIG-1))));
 #define EXP_SHIFT       (FLOAT_MANT_DIG-1)
@@ -468,15 +483,25 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
                 }
                 uint = UF_OR(uint, UF_LSHIFT_64(exp, EXP_SHIFT));
                 flt = ASFLOAT(uint);
-#else /* !defined(UINTFLOAT_128) || __LDBL_IS_IEC_60559__ != 0 */
+#else /* FLOAT_MANT_DIG <= 53 || __LDBL_IS_IEC_60559__ != 0 */
                 flt = scalbnl(TOFLOAT(uint), exp - (FLOAT_MANT_DIG-1));
 #endif
+                CHECK_RANGE(flt);
             }
         }
         else
 #endif
         {
-            if (CHECK_LONG())
+#ifdef _NEED_IO_FLOAT_LARGE
+            if (CHECK_LONG_LONG() && __SIZEOF_LONG_DOUBLE__ > 8)
+            {
+                flt = (FLOAT) __atold_engine(UF_TO_U128(uint), exp);
+            }
+            else
+#endif
+#ifdef _NEED_IO_FLOAT64
+            if ((CHECK_LONG() && __SIZEOF_DOUBLE__ == 8) ||
+                     (CHECK_LONG_LONG() && __SIZEOF_LONG_DOUBLE__ == 8))
             {
 		if (uintdigits + exp <= -324) {
                     // Number is less than 1e-324, which should be rounded down to 0; return +/-0.0.
@@ -488,11 +513,8 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
                     flt = (FLOAT) __atod_engine(UF_TO_U64(uint), exp);
                 }
             }
-            else if (CHECK_LONG_LONG())
-            {
-                flt = (FLOAT) __atold_engine(UF_TO_U128(uint), exp);
-            }
             else
+#endif
             {
 		if (uintdigits + exp <= -46) {
                     // Number is less than 1e-46, which should be rounded down to 0; return 0.0.
@@ -512,10 +534,10 @@ conv_flt (FLT_STREAM *stream, int *lenp, width_t width, void *addr, uint16_t fla
     if (flags & FL_MINUS)
 	flt = -flt;
     if (addr) {
-	if (CHECK_LONG())
-	    *((double *) addr) = (double) flt;
-	else if (CHECK_LONG_LONG())
+	if (CHECK_LONG_LONG())
             *((long double *) addr) = (long double) flt;
+	else if (CHECK_LONG())
+	    *((double *) addr) = (double) flt;
         else
 	    *((float *) addr) = (float) flt;
     }
