@@ -33,10 +33,15 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "dtoa_engine.h"
-#include <_ansi.h>
-#include <stdlib.h>
-#include <string.h>
+#include "stdio_private.h"
+
+#if __SIZEOF_DOUBLE__ == 8
+
+#define _NEED_IO_DOUBLE
+
+#include "dtoa.h"
+
+static NEWLIB_THREAD_LOCAL char ecvt_buf[DTOA_MAX_DIG + 1];
 
 char *
 ecvt (double invalue,
@@ -44,5 +49,20 @@ ecvt (double invalue,
       int *decpt,
       int *sign)
 {
-	return ecvtbuf(invalue, ndigit, decpt, sign, __ecvt_buf);
+    if (ecvt_r(invalue, ndigit, decpt, sign, ecvt_buf, sizeof(ecvt_buf)) < 0)
+        return NULL;
+    return ecvt_buf;
 }
+
+
+#elif __SIZEOF_DOUBLE__ == 4
+char *
+ecvt (double invalue,
+      int ndigit,
+      int *decpt,
+      int *sign)
+{
+    return ecvtf((float) invalue, ndigit, decpt, sign);
+}
+
+#endif
