@@ -29,9 +29,7 @@
 
 /* $Id: fgetc.c 1944 2009-04-01 23:12:20Z arcanum $ */
 
-#include <stdio.h>
 #include "stdio_private.h"
-#include <sys/cdefs.h>
 
 int
 fgetc(FILE *stream)
