@@ -29,9 +29,7 @@
 
 /* $Id: fputc.c 1944 2009-04-01 23:12:20Z arcanum $ */
 
-#include <stdio.h>
 #include "stdio_private.h"
-#include <sys/cdefs.h>
 
 int
 fputc(int c, FILE *stream)
@@ -39,13 +37,15 @@ fputc(int c, FILE *stream)
 	if ((stream->flags & __SWR) == 0)
 		return EOF;
 
-	if (stream->put(c, stream) < 0)
+	if (stream->put(c, stream) < 0) {
+                stream->flags |= __SERR;
 		return EOF;
+        }
 
-	return c;
+	return (unsigned char) c;
 }
 
-#ifdef HAVE_ALIAS_ATTRIBUTE
+#ifdef _HAVE_ALIAS_ATTRIBUTE
 __strong_reference(fputc, putc);
 #elif !defined(getc)
 int putc(int c, FILE *stream) { return fputc(c, stream); }
