@@ -24,8 +24,8 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-#include "ftoa_engine.h"
-#include <stdint.h>
+#define _NEED_IO_FLOAT32
+#include "dtoa.h"
 
 /*
  * 2^b ~= f * r * 10^e
@@ -87,7 +87,7 @@ static const uint32_t factorTable[32] = {
 		__typeof(b) _b = b;\
 		_a < _b ? _a : _b; })
 
-int __ftoa_engine(float val, struct ftoa *ftoa, int maxDigits, int maxDecimals) 
+int __ftoa_engine(float val, struct dtoa *ftoa, int maxDigits, bool fmode, int maxDecimals) 
 {
     uint8_t flags = 0;
 
@@ -105,8 +105,8 @@ int __ftoa_engine(float val, struct ftoa *ftoa, int maxDigits, int maxDecimals)
 
     /* Read the sign, shift the exponent in place and delete it from frac.
      */
-    if (x.u & (1 << 31))
-        flags = FTOA_MINUS;
+    if (x.u & ((uint32_t)1 << 31))
+        flags = DTOA_MINUS;
 
     uint8_t exp = x.u >> 23;
 
@@ -117,14 +117,14 @@ int __ftoa_engine(float val, struct ftoa *ftoa, int maxDigits, int maxDecimals)
      */
     if(exp==0 && frac==0)
     {
-        flags |= FTOA_ZERO;
+        flags |= DTOA_ZERO;
 	ftoa->digits[0] = '0';
 	maxDigits = 1;
     } else if(exp == 0xff) {
         if(frac == 0)
-            flags |= FTOA_INF;
+            flags |= DTOA_INF;
         else
-            flags |= FTOA_NAN;
+            flags |= DTOA_NAN;
     } else {
 
         /* The implicit leading 1 is made explicit, except if value
@@ -184,9 +184,9 @@ int __ftoa_engine(float val, struct ftoa *ftoa, int maxDigits, int maxDecimals)
                 hadNonzeroDigit = 1;
 
                 /* If limiting decimals... */
-                if(maxDecimals != 0)
+                if(fmode)
                 {
-		    maxDigits = min(maxDigits, max(0, maxDecimals - 1 + exp10 + 1));
+		    maxDigits = min(maxDigits, max(1, maxDecimals + exp10 + 1));
 		    if (maxDigits == 0)
 			break;
                 }
@@ -241,14 +241,13 @@ int __ftoa_engine(float val, struct ftoa *ftoa, int maxDigits, int maxDecimals)
                  */
 		ftoa->digits[0] = '1';
 		exp10++;
-		if (maxDecimals != 0)
-		    maxDigits = min(saveMaxDigits, max(0, maxDecimals - 1 + exp10 + 1));
-		flags |= FTOA_CARRY;
+		if (fmode)
+		    maxDigits = min(saveMaxDigits, max(1, maxDecimals + exp10 + 1));
+		flags |= DTOA_CARRY;
 	    }
         }
         ftoa->exp = exp10;
     }
     ftoa->flags = flags;
-    ftoa->digits[maxDigits] = '\0';
     return maxDigits;
 }
