@@ -33,10 +33,6 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#define _XOPEN_SOURCE
-#define _XOPEN_SOURCE_EXTENDED
-#include <_ansi.h>
-#include <stdlib.h>
 #include "stdio_private.h"
 
 char *
