@@ -31,14 +31,6 @@
 /* $Id: strtod.c 2191 2010-11-05 13:45:57Z arcanum $ */
 
 
-#include <ctype.h>
-#include <errno.h>
-#include <limits.h>
-#include <math.h>		/* INFINITY, NAN		*/
-#include <string.h>
-#include <stdlib.h>
-#include <inttypes.h>
-
 /**  The strtod() function converts the initial portion of the string pointed
      to by \a nptr to double representation.
 
@@ -65,10 +57,10 @@
      returned and \c ERANGE is stored in \c errno.
  */
 
-#include "stdio_private.h"
-
 #define STRTOD
 
+#include "stdio_private.h"
+
 #include "conv_flt.c"
 
 double
@@ -78,7 +70,7 @@ strtod (const char * nptr, char ** endptr)
     double flt;
     unsigned char ret;
 
-    while (ISSPACE(nptr[len]))
+    while (isspace(nptr[len]))
         len++;
 
     ret = conv_flt(nptr, &len, INT_MAX, &flt, FL_LONG);
@@ -91,8 +83,11 @@ strtod (const char * nptr, char ** endptr)
     return flt;
 }
 
-#if defined(_HAVE_LONG_DOUBLE) && defined(_LDBL_EQ_DBL)
-#ifdef HAVE_ALIAS_ATTRIBUTE
+#if defined(_HAVE_LONG_DOUBLE) && __SIZEOF_LONG_DOUBLE__ == __SIZEOF_DOUBLE__
+#ifdef _HAVE_ALIAS_ATTRIBUTE
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wunknown-warning-option"
+#pragma GCC diagnostic ignored "-Wattribute-alias="
 extern long double strtold(const char *, char **) __attribute__ ((__alias__ ("strtod")));
 #else
 long double
