@@ -33,11 +33,7 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#define _DEFAULT_SOURCE
-#include <_ansi.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
+#include "stdio_private.h"
 
 double
 strtod_l (const char *__restrict s00,
@@ -50,7 +46,10 @@ strtod_l (const char *__restrict s00,
 
 
 #if defined(_HAVE_LONG_DOUBLE) && defined(_LDBL_EQ_DBL)
-#ifdef HAVE_ALIAS_ATTRIBUTE
+#ifdef _HAVE_ALIAS_ATTRIBUTE
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wunknown-warning-option"
+#pragma GCC diagnostic ignored "-Wattribute-alias="
 extern long double strtold_l(const char *, char **, locale_t loc) __attribute__ ((__alias__ ("strtod_l")));
 #else
 long double
