@@ -31,14 +31,14 @@
 */
 
 #define SCANF_LEVEL SCANF_STD
-#ifndef FORMAT_DEFAULT_INTEGER
+#ifndef _FORMAT_DEFAULT_INTEGER
 #define vfscanf __i_vfscanf
 #endif
 
 #include "vfscanf.c"
 
-#ifdef FORMAT_DEFAULT_INTEGER
-#ifdef HAVE_ALIAS_ATTRIBUTE
+#ifdef _FORMAT_DEFAULT_INTEGER
+#ifdef _HAVE_ALIAS_ATTRIBUTE
 __strong_reference(vfscanf, __i_vfscanf);
 #else
 int __i_vfscanf (FILE * stream, const char *fmt, va_list ap) { return vfscanf(stream, fmt, ap); }
