@@ -29,9 +29,6 @@
 
 /* $Id: vsprintf.c 1944 2009-04-01 23:12:20Z arcanum $ */
 
-#include <limits.h>
-#include <stdarg.h>
-#include <stdio.h>
 #include "stdio_private.h"
 
 int
