@@ -29,8 +29,11 @@
 #include "fdlibm.h"
 #include "math_config.h"
 
+static CONST_FORCE_FLOAT VAL = pick_float_except(FLT_MIN, 0.0f);
+
 HIDDEN float
 __math_uflowf (uint32_t sign)
 {
-  return __math_xflowf (sign, 0x1p-95f);
+    float y = pick_float_except((sign ? -VAL : VAL) * VAL, sign ? -VAL : VAL);
+    return __math_with_errnof (y, ERANGE);
 }
