@@ -53,7 +53,7 @@ float scalbnf (float x, int n)
             return __math_oflowf(ix<0);          /* overflow  */
         if (k > 0) 				/* normal result */
 	    {SET_FLOAT_WORD(x,(ix&0x807fffff)|(k<<23)); return x;}
-        if (k < -25)
+        if (k <= -25)
 	    return __math_uflowf(ix<0);	        /*underflow*/
         k += 25;				/* subnormal result */
 	SET_FLOAT_WORD(x,(ix&0x807fffff)|(k<<23));
