@@ -39,14 +39,12 @@ PORTABILITY
 long double complex
 clog10l(long double complex z)
 {
-	long double complex w;
 	long double p, rr;
 
 	rr = cabsl(z);
 	p = log10l(rr);
 	rr = atan2l(cimagl(z), creall(z)) * _M_IVLN10L;
-	w = p + rr * (long double complex) I;
-	return w;
+	return (long double complex) p + rr * (long double complex) I;
 }
 
 #endif
