@@ -26,16 +26,11 @@
 
 #define _GNU_SOURCE
 #include <sys/cdefs.h>
-#if 0
-__FBSDID("$FreeBSD: head/lib/msun/src/s_csqrtl.c 181402 2008-08-08 00:15:16Z das $");
-#else
-__RCSID("$NetBSD: csqrtl.c,v 1.2 2014/10/11 00:43:51 christos Exp $");
-#endif
-
 #include <complex.h>
 #include <float.h>
 #include <math.h>
 #include <stdbool.h>
+
 /*
  * gcc doesn't implement complex multiplication or division correctly,
  * so we need to handle infinities specially. We turn on this pragma to
