@@ -37,15 +37,12 @@
 long double complex
 ctanhl(long double complex z)
 {
-	long double complex w;
 	long double x, y, d;
 
 	x = creall(z);
 	y = cimagl(z);
 	d = coshl(2.0L * x) + cosl(2.0L * y);
-	w = sinhl(2.0L * x) / d  +  (sinl(2.0L * y) / d) * (long double complex) I;
-
-	return w;
+	return (long double complex) (sinhl(2.0L * x) / d)  +  (sinl(2.0L * y) / d) * (long double complex) I;
 }
 
 #endif
