@@ -39,7 +39,8 @@
 
 #include <math.h>
 
-#if defined(__riscv_flen) && __riscv_flen >= 64
+#if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 64
+
 int finite(double x)
 {
 	long fclass = _fclass_d (x);
