@@ -28,12 +28,4 @@ fabsf(float x)
     return x;
 }
 
-#ifdef _DOUBLE_IS_32BITS
-
-double
-fabs(double x)
-{
-    return (double)fabsf((float)x);
-}
-
-#endif /* defined(_DOUBLE_IS_32BITS) */
+_MATH_ALIAS_f_f(fabs)
