@@ -19,12 +19,16 @@
 float
 scalbf(float x, float fn)
 {
-    if (isnan(fn))
-        return fn;
+    if (isnan(fn) || isnan(x))
+        return x + fn;
 
     if (isinf(fn)) {
         if ((x == 0.0f && fn > 0.0f) || (isinf(x) && fn < 0.0f))
             return __math_invalidf(fn);
+        if (fn > 0.0f)
+            return fn*x;
+        else
+            return x/(-fn);
     }
 
     if (rintf(fn) != fn)
@@ -38,3 +42,5 @@ scalbf(float x, float fn)
 
     return scalbnf(x, (int)fn);
 }
+
+_MATH_ALIAS_f_ff(scalb)
