@@ -49,20 +49,15 @@ sinf(float x)
     }
 }
 
-#if defined(HAVE_ALIAS_ATTRIBUTE)
+#if defined(_HAVE_ALIAS_ATTRIBUTE)
 #ifndef __clang__
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(sinf, _sinf);
 #endif
 
-#ifdef _DOUBLE_IS_32BITS
+_MATH_ALIAS_f_f(sin)
 
-double
-sin(double x)
-{
-    return (double)sinf((float)x);
-}
-
-#endif /* defined(_DOUBLE_IS_32BITS) */
+#else
+#include "../common/sinf.c"
 #endif /* __OBSOLETE_MATH_FLOAT */
