@@ -300,5 +300,6 @@
 { 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x403a1999, 0x99999996},	/* -nan=f(26.1)*/
 { 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* -nan=f(27.8)*/
 { 0, 0, 33,__LINE__, 0xfff80000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* -nan=f(29.5)*/
-0,};
-void test_atanh(m)   {run_vector_1(m,atanh_vec,(char *)(atanh),"atanh","dd");   }	
+{0},
+};
+void test_atanh(int m)   {run_vector_1(m,atanh_vec,(char *)(atanh),"atanh","dd");   }	
