@@ -55,7 +55,10 @@ _start(void)
 {
 	/* Generate a reference to __interrupt_vector so we get one loaded */
 	__asm__(".equ __my_interrupt_vector, __interrupt_vector");
-#ifndef __SOFTFP__
+    /* Access to the coprocessor has to be enabled in CPACR, if either FPU or
+     * MVE is used. This is described in "Arm v8-M Architecture Reference
+     * Manual". */
+#if defined __ARM_FP || defined __ARM_FEATURE_MVE
 	/* Enable FPU */
 	*CPACR |= 0xf << 20;
 	/*
@@ -101,20 +104,20 @@ _start(void)
 	/* Initialize stack pointer */
 	__asm__("mov sp, %0" : : "r" (__stack));
 
-#if __ARM_ARCH == 7
-#ifdef __thumb__
+#ifdef __thumb2__
 	/* Make exceptions run in Thumb mode */
 	uint32_t sctlr;
 	__asm__("mrc p15, 0, %0, c1, c0, 0" : "=r" (sctlr));
 	sctlr |= (1 << 30);
 	__asm__("mcr p15, 0, %0, c1, c0, 0" : : "r" (sctlr));
 #endif
-#ifndef __SOFTFP__
+#if defined __ARM_FP || defined __ARM_FEATURE_MVE
+#if __ARM_ARCH > 6
 	/* Set CPACR for access to CP10 and 11 */
 	__asm__("mcr p15, 0, %0, c1, c0, 2" : : "r" (0xf << 20));
+#endif
 	/* Enable FPU */
 	__asm__("vmsr fpexc, %0" : : "r" (0x40000000));
-#endif
 #endif
 
 	/* Branch to C code */
