@@ -22,6 +22,7 @@
  */
 #define _GNU_SOURCE
 #include <stdlib.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -32,7 +33,8 @@ static int scmp(const void *a, const void *b)
 
 static int icmp(const void *a, const void *b)
 {
-	return *(int*)a - *(int*)b;
+        long d = *(long*)a - *(long*)b;
+	return (d > 0) ? 1 : (d < 0) ? -1 : 0;
 }
 
 struct three {
@@ -40,7 +42,7 @@ struct three {
 };
 
 #define i3(x)                                                    \
-        { (unsigned char) ((x) >> 16), (unsigned char) ((x) >> 8),      \
+        { (unsigned char) (((int32_t)(x)) >> 16), (unsigned char) ((x) >> 8), \
                         (unsigned char) ((x) >> 0) }
 
 static int tcmp(const void *av, const void *bv)
@@ -62,34 +64,35 @@ static int tcmp(const void *av, const void *bv)
         err++;                                                  \
     } while(0)
 
+/* 26 items -- even */
+static char *s[] = {
+    "Bob", "Alice", "John", "Ceres",
+    "Helga", "Drepper", "Emeralda", "Zoran",
+    "Momo", "Frank", "Pema", "Xavier",
+    "Yeva", "Gedun", "Irina", "Nono",
+    "Wiener", "Vincent", "Tsering", "Karnica",
+    "Lulu", "Quincy", "Osama", "Riley",
+    "Ursula", "Sam"
+};
+/* 23 items -- odd, prime */
+static long n[] = {
+    879045, 394, 99405644, 33434, 232323, 4334, 5454,
+    343, 45545, 454, 324, 22, 34344, 233, 45345, 343,
+    848405, 3434, 3434344, 3535, 93994, 2230404, 4334
+};
+
+static struct three t[] = {
+    i3(879045), i3(394), i3(99405644), i3(33434), i3(232323), i3(4334), i3(5454),
+    i3(343), i3(45545), i3(454), i3(324), i3(22), i3(34344), i3(233), i3(45345), i3(343),
+    i3(848405), i3(3434), i3(3434344), i3(3535), i3(93994), i3(2230404), i3(4334)
+};
+
 int test_qsort(void)
 {
 	int i;
 	int err=0;
-	/* 26 items -- even */
-	char *s[] = {
-		"Bob", "Alice", "John", "Ceres",
-		"Helga", "Drepper", "Emeralda", "Zoran",
-		"Momo", "Frank", "Pema", "Xavier",
-		"Yeva", "Gedun", "Irina", "Nono",
-		"Wiener", "Vincent", "Tsering", "Karnica",
-		"Lulu", "Quincy", "Osama", "Riley",
-		"Ursula", "Sam"
-	};
-	/* 23 items -- odd, prime */
-	int n[] = {
-		879045, 394, 99405644, 33434, 232323, 4334, 5454,
-		343, 45545, 454, 324, 22, 34344, 233, 45345, 343,
-		848405, 3434, 3434344, 3535, 93994, 2230404, 4334
-	};
 
-        struct three t[] = {
-                i3(879045), i3(394), i3(99405644), i3(33434), i3(232323), i3(4334), i3(5454),
-                i3(343), i3(45545), i3(454), i3(324), i3(22), i3(34344), i3(233), i3(45345), i3(343),
-                i3(848405), i3(3434), i3(3434344), i3(3535), i3(93994), i3(2230404), i3(4334)
-        };
-
-	qsort(s, sizeof(s)/sizeof(char *), sizeof(char *), scmp);
+	qsort(s, sizeof(s)/sizeof(s[0]), sizeof(s[0]), scmp);
 	for (i=0; i<(int) (sizeof(s)/sizeof(char *)-1); i++) {
 		if (strcmp(s[i], s[i+1]) > 0) {
 			FAIL("string sort");
@@ -99,12 +102,12 @@ int test_qsort(void)
 		}
 	}
 
-	qsort(n, sizeof(n)/sizeof(int), sizeof(int), icmp);
-	for (i=0; i<(int)(sizeof(n)/sizeof(int)-1); i++) {
+	qsort(n, sizeof(n)/sizeof(n[0]), sizeof(n[0]), icmp);
+	for (i=0; i<(int)(sizeof(n)/sizeof(n[0])-1); i++) {
 		if (n[i] > n[i+1]) {
 			FAIL("integer sort");
-			for (i=0; i<(int)(sizeof(n)/sizeof(int)); i++)
-				printf("\t%d\n", n[i]);
+			for (i=0; i<(int)(sizeof(n)/sizeof(n[0])); i++)
+				printf("\t%ld\n", n[i]);
 			break;
 		}
 	}
